@@ -1,8 +1,7 @@
-pub fn split_address<S: Into<String>>(address: S) -> (String, String) {
-    let value = address.into();
+pub fn split_address(address: &str) -> (String, String) {
     let mut sheet_name = String::from("");
     let mut range = String::from("");
-    let split_value: Vec<&str> = value.split("!").collect();
+    let split_value: Vec<&str> = address.split('!').collect();
     if split_value.len() == 1 {
         range = split_value[0].to_string();
     } else if split_value.len() == 2 {
