@@ -1,26 +1,28 @@
 use regex::Regex;
 
-const ALPHABET: &'static [&'static str] = &[
+const ALPHABET: &[&str] = &[
     "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S",
     "T", "U", "V", "W", "X", "Y", "Z",
 ];
 
-pub fn column_index_from_string<S: Into<String>>(column: S) -> u32 {
-    let column_c = column.into().clone();
+pub fn column_index_from_string<S: AsRef<str>>(column: S) -> u32 {
+    let column_c = column.as_ref();
     if column_c == "0" {
         return 0;
     }
     match column_c.len() {
         3 => {
-            get_index(&column_c.chars().nth(0).unwrap().to_string()) * 676
-                + get_index(&column_c.chars().nth(1).unwrap().to_string()) * 26
-                + get_index(&column_c.chars().nth(2).unwrap().to_string())
+            let a = &column_c[0..1];
+            let b = &column_c[1..2];
+            let c = &column_c[2..3];
+            get_index(a) * 676 + get_index(b) * 26 + get_index(c)
         }
         2 => {
-            get_index(&column_c.chars().nth(0).unwrap().to_string()) * 26
-                + get_index(&column_c.chars().nth(1).unwrap().to_string())
+            let a = &column_c[0..1];
+            let b = &column_c[1..2];
+            get_index(a) * 26 + get_index(b)
         }
-        1 => get_index(&column_c.chars().nth(0).unwrap().to_string()),
+        1 => get_index(&column_c[0..1]),
         _ => {
             panic!("longer than 3 characters");
         }
@@ -28,14 +30,11 @@ pub fn column_index_from_string<S: Into<String>>(column: S) -> u32 {
 }
 
 fn get_index(column: &str) -> u32 {
-    let mut i = 0;
-    for tar in self::ALPHABET {
-        if tar == &column {
-            return i + 1;
-        }
-        i += 1;
-    }
-    panic!("illegal character");
+    self::ALPHABET
+        .iter()
+        .enumerate()
+        .find_map(|(i, tar)| (tar == &column).then(|| i as u32))
+        .expect("illegal character") + 1
 }
 
 pub fn string_from_column_index(column_index: &u32) -> String {
@@ -57,12 +56,11 @@ pub fn string_from_column_index(column_index: &u32) -> String {
 }
 
 pub fn coordinate_from_string(coordinate: &str) -> Vec<Option<&str>> {
-    let re = Regex::new(r"[A-Z]+").unwrap();
-    let caps = re.captures(coordinate);
-    let col = match caps {
-        Some(v) => Some(v.get(0).unwrap().as_str()),
-        None => None,
-    };
+    lazy_static! {
+        static ref RE: Regex = Regex::new(r"[A-Z]+").unwrap();
+    }
+    let caps = RE.captures(coordinate);
+    let col = caps.map(|v| v.get(0).unwrap().as_str());
     let is_lock_col = match col {
         Some(v) => match coordinate.find(format!("{}{}", "$", v).as_str()) {
             Some(_) => Some("1"),
@@ -71,12 +69,11 @@ pub fn coordinate_from_string(coordinate: &str) -> Vec<Option<&str>> {
         None => None,
     };
 
-    let re = Regex::new(r"[0-9]+").unwrap();
-    let caps = re.captures(coordinate);
-    let row = match caps {
-        Some(v) => Some(v.get(0).unwrap().as_str()),
-        None => None,
-    };
+    lazy_static! {
+        static ref RE_NUM: Regex = Regex::new(r"[0-9]+").unwrap();
+    }
+    let caps = RE_NUM.captures(coordinate);
+    let row = caps.map(|v| v.get(0).unwrap().as_str());
     let is_lock_row = match row {
         Some(v) => match coordinate.find(format!("{}{}", "$", v).as_str()) {
             Some(_) => Some("1"),
@@ -89,7 +86,7 @@ pub fn coordinate_from_string(coordinate: &str) -> Vec<Option<&str>> {
 }
 
 pub fn coordinate_from_index(col: &u32, row: &u32) -> String {
-    format!("{}{}", string_from_column_index(&col), row)
+    format!("{}{}", string_from_column_index(col), row)
 }
 
 pub fn coordinate_from_index_with_lock(
@@ -101,36 +98,31 @@ pub fn coordinate_from_index_with_lock(
     format!(
         "{}{}{}{}",
         if is_lock_col == &true { "$" } else { "" },
-        string_from_column_index(&col),
+        string_from_column_index(col),
         if is_lock_row == &true { "$" } else { "" },
         row
     )
 }
 
-pub fn index_from_coordinate<S: Into<String>>(coordinate: S) -> Vec<Option<u32>> {
-    let con = coordinate.into();
-    let split = coordinate_from_string(con.as_str());
-    let col = match split[0] {
-        Some(v) => Some(column_index_from_string(v)),
-        None => None,
-    };
-    let row = match split[1] {
-        Some(v) => Some(v.parse::<u32>().unwrap()),
-        None => None,
-    };
-    let is_lock_col = match split[2] {
-        Some(v) => Some(v.parse::<u32>().unwrap()),
-        None => None,
-    };
-    let is_lock_row = match split[3] {
-        Some(v) => Some(v.parse::<u32>().unwrap()),
-        None => None,
-    };
+pub fn index_from_coordinate<S: AsRef<str>>(coordinate: S) -> Vec<Option<u32>> {
+    let split = coordinate_from_string(coordinate.as_ref());
+    let col = split[0].map(column_index_from_string);
+    let row = split[1].map(|v| v.parse::<u32>().unwrap());
+    let is_lock_col = split[2].map(|v| v.parse::<u32>().unwrap());
+    let is_lock_row = split[3].map(|v| v.parse::<u32>().unwrap());
     vec![col, row, is_lock_col, is_lock_row]
 }
 
+pub fn index_from_coordinate_simple(coordinate: &str) -> (u32, u32) {
+    let coordinate_upper = coordinate.to_uppercase();
+    let split = index_from_coordinate(&coordinate_upper);
+    let col = split[0].unwrap();
+    let row = split[1].unwrap();
+    (col, row)
+}
+
 pub(crate) fn adjustment_insert_coordinate(num: &u32, root_num: &u32, offset_num: &u32) -> u32 {
-    let mut result = num.clone();
+    let mut result = *num;
     if (num >= root_num && offset_num > &0) || (num < root_num && offset_num < &0) {
         result += offset_num;
     }
@@ -138,7 +130,7 @@ pub(crate) fn adjustment_insert_coordinate(num: &u32, root_num: &u32, offset_num
 }
 
 pub(crate) fn adjustment_remove_coordinate(num: &u32, root_num: &u32, offset_num: &u32) -> u32 {
-    let mut result = num.clone();
+    let mut result = *num;
     if (num >= root_num && offset_num > &0) || (num < root_num && offset_num < &0) {
         result -= offset_num;
     }
