@@ -1,10 +1,8 @@
 use helper::coordinate::*;
 
-pub fn get_coordinate_list<S: Into<String>>(range_str: S) -> Vec<(u32, u32)> {
-    let value = range_str.into();
-    let coordinate_collection: Vec<&str> = value.split(":").collect();
-
-    if coordinate_collection.len() == 0 || coordinate_collection.len() > 2 {
+pub fn get_coordinate_list(range_str: &str) -> Vec<(u32, u32)> {
+    let coordinate_collection: Vec<&str> = range_str.split(':').collect();
+    if coordinate_collection.is_empty() || coordinate_collection.len() > 2 {
         panic!("Non-standard range.");
     }
 
@@ -46,7 +44,7 @@ pub fn get_coordinate_list<S: Into<String>>(range_str: S) -> Vec<(u32, u32)> {
                 col_end = v;
             }
             None => {
-                if is_col_select == false {
+                if !is_col_select {
                     panic!("Non-standard range.");
                 }
             }
@@ -56,7 +54,7 @@ pub fn get_coordinate_list<S: Into<String>>(range_str: S) -> Vec<(u32, u32)> {
                 row_end = v;
             }
             None => {
-                if is_row_select == false {
+                if !is_row_select {
                     panic!("Non-standard range.");
                 }
             }
