@@ -31,7 +31,7 @@
 //! let mut book = new_file();
 //!
 //! let mut clone_sheet = book.get_sheet(0).unwrap().clone();
-//! clone_sheet.set_title("New Sheet");
+//! clone_sheet.set_name("New Sheet");
 //! let _ = book.add_sheet(clone_sheet);
 //! ```
 //! ### Change value
@@ -94,17 +94,17 @@
 //! book.insert_new_row("Sheet1", 2, 3);
 //!
 //! // insert columns
-//! book.insert_new_colmun("Sheet1", "B", 3);
+//! book.insert_new_column("Sheet1", "B", 3);
 //! // or
-//! book.insert_new_colmun_by_index("Sheet1", 2, 3);
+//! book.insert_new_column_by_index("Sheet1", 2, 3);
 //!
 //! // remove rows
 //! book.remove_row("Sheet1", 6, 2);
 //!
 //! // remove columns
-//! book.remove_colmun("Sheet1", "F", 2);
+//! book.remove_column("Sheet1", "F", 2);
 //! // or
-//! book.remove_colmun_by_index("Sheet1", 6, 2);
+//! book.remove_column_by_index("Sheet1", 6, 2);
 //! ```
 //! ### Writer
 //! ```rust
@@ -116,55 +116,16 @@
 //! let path = std::path::Path::new("C:/spread_test_data/ccc.xlsx");
 //! let _ = writer::xlsx::write(&book, path);
 //! ```
-//! ## Supported graph types
-//! * AreaChart
-//! * Area3DChart
-//! * BarChart
-//! * Bar3DChart
-//! * BubbleChart
-//! * DoughnutChart
-//! * LineChart
-//! * Line3DChart
-//! * OfPieChart
-//! * PieChart
-//! * RadarChart
-//! * ScatterChart
-//!
-//! Other types will be supported sequentially.
-//!
-//! ## Add Chart
-//! ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/sample3.png)
-//! ```rust
-//! extern crate umya_spreadsheet;
-//!
-//! let mut book = umya_spreadsheet::new_file();
-//!
-//! // add chart
-//! let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
-//! let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
-//! from_marker.set_coordinate("C1");
-//! to_marker.set_coordinate("D11");
-//! let area_chart_series_list = vec![
-//!     "Sheet1!$A$1:$A$10",
-//!     "Sheet1!$B$1:$B$10",
-//! ];
-//! let mut chart = umya_spreadsheet::structs::Chart::default();
-//! chart.new_chart(
-//!     umya_spreadsheet::structs::ChartType::LineChart,
-//!     from_marker,
-//!     to_marker,
-//!     area_chart_series_list,
-//! );
-//! book.get_sheet_by_name_mut("Sheet1").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
-//! ```
 
 extern crate chrono;
+extern crate image;
 extern crate md5;
 extern crate onig;
 extern crate quick_xml;
 extern crate regex;
 extern crate thousands;
 extern crate zip;
+extern crate hashbrown;
 
 #[macro_use]
 extern crate lazy_static;
@@ -190,5 +151,24 @@ pub fn new_file() -> structs::Spreadsheet {
     spreadsheet.set_stylesheet_defalut_value();
     let worksheet = spreadsheet.new_sheet("Sheet1").unwrap();
     worksheet.set_active_cell("A1");
+    spreadsheet.set_active_sheet(0);
+    spreadsheet
+}
+
+/// create new spreadsheet file.
+/// not include worksheet.
+/// At least one additional worksheet must be added before the correct file can be generated.
+///
+/// # Arguments
+/// # Return value
+/// * Spreadsheet structs object.
+/// # Examples
+/// ```
+/// let mut book = umya_spreadsheet::new_file_empty_worksheet();
+/// ```
+pub fn new_file_empty_worksheet() -> structs::Spreadsheet {
+    let mut spreadsheet = structs::Spreadsheet::default();
+    spreadsheet.set_theme(Theme::get_defalut_value());
+    spreadsheet.set_stylesheet_defalut_value();
     spreadsheet
 }
