@@ -32,7 +32,7 @@ pub(crate) fn normalize_path(path: &str) -> PathBuf {
 
 pub(crate) fn normalize_path_to_str(path: &str) -> String {
     let ret = normalize_path(path);
-    ret.to_str().unwrap_or("").to_string().replace("\\", "/")
+    ret.to_str().unwrap_or("").to_string().replace('\\', "/")
 }
 
 pub(crate) fn get_attribute(e: &quick_xml::events::BytesStart<'_>, key: &[u8]) -> Option<String> {
