@@ -2,6 +2,8 @@ use std::fs::File;
 use std::io;
 use std::path::Path;
 use std::string::FromUtf8Error;
+use std::sync::Arc;
+use std::sync::RwLock;
 
 use super::driver;
 use structs::raw::RawWorksheet;
@@ -13,6 +15,7 @@ use structs::Worksheet;
 
 pub(crate) mod chart;
 pub(crate) mod comment;
+mod content_types;
 mod doc_props_app;
 mod doc_props_core;
 pub(crate) mod drawing;
@@ -73,7 +76,8 @@ pub fn read_reader<R: io::Read + io::Seek>(
     doc_props_app::read(&mut arv, &mut book).unwrap();
     doc_props_core::read(&mut arv, &mut book).unwrap();
     vba_project_bin::read(&mut arv, &mut book).unwrap();
-    let workbook_rel = workbook_rels::read(&mut arv).unwrap();
+    content_types::read(&mut arv, &mut book).unwrap();
+    let workbook_rel = workbook_rels::read(&mut arv, &mut book).unwrap();
 
     for (_, type_value, rel_target) in &workbook_rel {
         match type_value.as_str() {
@@ -95,7 +99,7 @@ pub fn read_reader<R: io::Read + io::Seek>(
                 continue;
             }
             let mut raw_worksheet = RawWorksheet::default();
-            raw_worksheet.read(&mut arv, &rel_target);
+            raw_worksheet.read(&mut arv, rel_target);
             sheet.set_raw_data_of_worksheet(raw_worksheet);
         }
     }
@@ -142,7 +146,7 @@ pub fn lazy_read(path: &Path) -> Result<Spreadsheet, XlsxError> {
 pub(crate) fn raw_to_serialize_by_worksheet(
     worksheet: &mut Worksheet,
     theme: &Theme,
-    shared_string_table: &SharedStringTable,
+    shared_string_table: Arc<RwLock<SharedStringTable>>,
     stylesheet: &Stylesheet,
 ) {
     if worksheet.is_serialized() {
@@ -150,6 +154,7 @@ pub(crate) fn raw_to_serialize_by_worksheet(
     }
 
     let raw_data_of_worksheet = worksheet.get_raw_data_of_worksheet().clone();
+    let shared_string_table = &*shared_string_table.read().unwrap();
     worksheet::read(
         worksheet,
         &raw_data_of_worksheet,
@@ -159,43 +164,42 @@ pub(crate) fn raw_to_serialize_by_worksheet(
     )
     .unwrap();
 
-    for relationship in raw_data_of_worksheet
-        .get_relationships()
-        .get_relationship_list()
-    {
-        match relationship.get_type() {
-            // drawing, chart
-            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing" => {
-                drawing::read(
-                    worksheet,
-                    relationship.get_raw_file(),
-                    raw_data_of_worksheet.get_drawing_relationships(),
-                )
-                .unwrap();
+    match raw_data_of_worksheet.get_worksheet_relationships() {
+        Some(v) => {
+            for relationship in v.get_relationship_list() {
+                match relationship.get_type() {
+                    // drawing, chart
+                    "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing" => {
+                        drawing::read(
+                            worksheet,
+                            relationship.get_raw_file(),
+                            raw_data_of_worksheet.get_drawing_relationships(),
+                        )
+                        .unwrap();
+                    }
+                    // comment
+                    "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments" => {
+                        let _ = comment::read(worksheet, relationship.get_raw_file()).unwrap();
+                    }
+                    _ => {}
+                }
             }
-            // comment
-            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments" => {
-                let _ = comment::read(worksheet, relationship.get_raw_file()).unwrap();
+            for relationship in v.get_relationship_list() {
+                match relationship.get_type() {
+                    // vmlDrawing
+                    "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing" => {
+                        let _ = vml_drawing::read(
+                            worksheet,
+                            relationship.get_raw_file(),
+                            raw_data_of_worksheet.get_vml_drawing_relationships(),
+                        )
+                        .unwrap();
+                    }
+                    _ => {}
+                }
             }
-            _ => {}
-        }
-    }
-    for relationship in raw_data_of_worksheet
-        .get_relationships()
-        .get_relationship_list()
-    {
-        match relationship.get_type() {
-            // vmlDrawing
-            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing" => {
-                let _ = vml_drawing::read(
-                    worksheet,
-                    relationship.get_raw_file(),
-                    raw_data_of_worksheet.get_vml_drawing_relationships(),
-                )
-                .unwrap();
-            }
-            _ => {}
         }
+        None => {}
     }
 
     worksheet.remove_raw_data_of_worksheet();
