@@ -64,15 +64,15 @@ pub(crate) fn read(
                         &mut reader,
                         e,
                         worksheet,
-                        &shared_string_table,
-                        &stylesheet,
+                        shared_string_table,
+                        stylesheet,
                         false,
                     );
                     worksheet.set_row_dimension(obj);
                 }
                 b"cols" => {
                     let mut obj = Columns::default();
-                    obj.set_attributes(&mut reader, e, &stylesheet);
+                    obj.set_attributes(&mut reader, e, stylesheet);
                     worksheet.set_column_dimensions_crate(obj);
                 }
                 b"mergeCells" => {
@@ -87,13 +87,17 @@ pub(crate) fn read(
                         .get_sequence_of_references_mut()
                         .set_sqref(sqref);
                     let conditional_styles_collection =
-                        get_conditional_formatting(&mut reader, &stylesheet, &theme);
+                        get_conditional_formatting(&mut reader, stylesheet, theme);
                     conditional_set.set_conditional_collection(conditional_styles_collection);
                     worksheet.add_conditional_styles_collection(conditional_set);
                 }
                 b"oleObjects" => {
                     let mut obj = OleObjects::default();
-                    obj.set_attributes(&mut reader, e, raw_data_of_worksheet.get_relationships());
+                    obj.set_attributes(
+                        &mut reader,
+                        e,
+                        raw_data_of_worksheet.get_worksheet_relationships().unwrap(),
+                    );
                     worksheet.set_ole_objects(obj);
                 }
                 b"headerFooter" => {
@@ -127,7 +131,7 @@ pub(crate) fn read(
                 }
                 b"tabColor" => {
                     worksheet.get_tab_color_mut().set_attributes(&mut reader, e);
-                    worksheet.get_tab_color_mut().set_argb_by_theme(&theme);
+                    worksheet.get_tab_color_mut().set_argb_by_theme(theme);
                 }
                 b"selection" => {
                     for a in e.attributes().with_checks(false) {
@@ -146,8 +150,8 @@ pub(crate) fn read(
                         &mut reader,
                         e,
                         worksheet,
-                        &shared_string_table,
-                        &stylesheet,
+                        shared_string_table,
+                        stylesheet,
                         true,
                     );
                     worksheet.set_row_dimension(obj);
@@ -175,7 +179,7 @@ pub(crate) fn read(
                     worksheet.get_page_setup_mut().set_attributes(
                         &mut reader,
                         e,
-                        raw_data_of_worksheet.get_relationships(),
+                        raw_data_of_worksheet.get_worksheet_relationships(),
                     );
                 }
                 _ => (),
