@@ -4,6 +4,7 @@ use quick_xml::Reader;
 use quick_xml::Writer;
 use reader::driver::*;
 use std::io::Cursor;
+use std::sync::{Arc, RwLock};
 use structs::CellValue;
 use structs::Coordinate;
 use structs::Hyperlink;
@@ -233,7 +234,14 @@ impl Cell {
     }
 
     pub fn get_formula(&self) -> &str {
-        &self.cell_value.get_formula()
+        self.cell_value.get_formula()
+    }
+
+    pub(crate) fn get_formula_attributes(&self) -> Vec<(&str, &str)> {
+        self.cell_value.get_formula_attributes()
+    }
+    pub(crate) fn set_formula_attributes(&mut self, attributes: Vec<(String, String)>) {
+        self.cell_value.set_formula_attributes(attributes);
     }
 
     pub(crate) fn get_width_point(&self, column_font_size: &f64) -> f64 {
@@ -255,7 +263,7 @@ impl Cell {
     pub(crate) fn get_width_point_cell(&self) -> f64 {
         let mut max_point = 0f64;
         let value = self.get_formatted_value();
-        let value_list: Vec<&str> = value.split("\n").collect();
+        let value_list: Vec<&str> = value.split('\n').collect();
         for value in value_list {
             let mut point = 0f64;
             for chr in value.chars() {
@@ -330,7 +338,23 @@ impl Cell {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Text(e)) => string_value = e.unescape_and_decode(&reader).unwrap(),
+                Ok(Event::Text(e)) => string_value = e.unescape_and_decode(reader).unwrap(),
+                Ok(Event::Start(ref s)) => {
+                    if s.name() == b"f" {
+                        let mut attrs = vec![];
+                        s.attributes().for_each(|a| {
+                            if let Ok(attribute) = a {
+                                if let (Ok(key), Ok(value)) = (
+                                    std::str::from_utf8(attribute.key),
+                                    std::str::from_utf8(attribute.value.as_ref()),
+                                ) {
+                                    attrs.push((key.to_owned(), value.to_owned()));
+                                }
+                            }
+                        });
+                        self.set_formula_attributes(attrs);
+                    }
+                }
                 Ok(Event::End(ref e)) => match e.name() {
                     b"f" => {
                         self.set_formula(string_value.clone());
@@ -344,9 +368,9 @@ impl Cell {
                                 .unwrap();
                             self.set_shared_string_item(shared_string_item.clone());
                         } else if type_value == "b" {
-                            let prm = if &string_value == "1" { true } else { false };
+                            let prm = &string_value == "1";
                             let _ = self.set_value_from_bool(prm);
-                        } else if type_value == "" || type_value == "n" {
+                        } else if type_value.is_empty() || type_value == "n" {
                             let _ = self.set_value(&string_value);
                         };
                     }
@@ -364,10 +388,14 @@ impl Cell {
     pub(crate) fn write_to(
         &self,
         writer: &mut Writer<Cursor<Vec<u8>>>,
-        shared_string_table: &mut SharedStringTable,
+        shared_string_table: Arc<RwLock<SharedStringTable>>,
         stylesheet: &mut Stylesheet,
     ) {
-        let empty_flag = self.cell_value.is_empty();
+        let empty_flag_value = self.cell_value.is_empty();
+        let empty_flag_style = self.style.is_empty();
+        if empty_flag_value && empty_flag_style {
+            return;
+        }
 
         // c
         let mut attributes: Vec<(&str, &str)> = Vec::new();
@@ -382,13 +410,13 @@ impl Cell {
             xf_index_str = xf_index.to_string();
             attributes.push(("s", &xf_index_str));
         }
-        write_start_tag(writer, "c", attributes, empty_flag);
 
-        if empty_flag == false {
+        if !empty_flag_value {
+            write_start_tag(writer, "c", attributes, false);
             // f
             match &self.cell_value.formula {
                 Some(v) => {
-                    write_start_tag(writer, "f", vec![], false);
+                    write_start_tag(writer, "f", self.get_formula_attributes(), false);
                     write_text_node(writer, v);
                     write_end_tag(writer, "f");
                 }
@@ -399,7 +427,10 @@ impl Cell {
             write_start_tag(writer, "v", vec![], false);
             match self.get_data_type() {
                 "s" => {
-                    let val_index = shared_string_table.set_cell(self.get_cell_value());
+                    let val_index = shared_string_table
+                        .write()
+                        .unwrap()
+                        .set_cell(self.get_cell_value());
                     write_text_node(writer, val_index.to_string());
                 }
                 "b" => {
@@ -412,6 +443,8 @@ impl Cell {
             write_end_tag(writer, "v");
 
             write_end_tag(writer, "c");
+        } else {
+            write_start_tag(writer, "c", attributes, true);
         }
     }
 }
