@@ -13,7 +13,7 @@ pub struct Bubble3D {
 }
 impl Bubble3D {
     pub fn get_val(&self) -> &bool {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: bool) -> &mut Bubble3D {
@@ -34,7 +34,7 @@ impl Bubble3D {
         write_start_tag(
             writer,
             "c:bubble3D",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
