@@ -13,7 +13,7 @@ pub struct CrossingAxis {
 }
 impl CrossingAxis {
     pub fn get_val(&self) -> &u32 {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: u32) -> &mut CrossingAxis {
@@ -34,7 +34,7 @@ impl CrossingAxis {
         write_start_tag(
             writer,
             "c:crossAx",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
