@@ -13,7 +13,7 @@ pub struct InvertIfNegative {
 }
 impl InvertIfNegative {
     pub fn get_val(&self) -> &f64 {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: f64) -> &mut InvertIfNegative {
@@ -34,7 +34,7 @@ impl InvertIfNegative {
         write_start_tag(
             writer,
             "c:invertIfNegative",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
