@@ -14,7 +14,7 @@ pub struct LeftMode {
 }
 impl LeftMode {
     pub fn get_val(&self) -> &LayoutModeValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: LayoutModeValues) -> &mut LeftMode {
@@ -35,7 +35,7 @@ impl LeftMode {
         write_start_tag(
             writer,
             "c:xMode",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
