@@ -14,7 +14,7 @@ pub struct OfPieType {
 }
 impl OfPieType {
     pub fn get_val(&self) -> &OfPieValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: OfPieValues) -> &mut OfPieType {
@@ -35,7 +35,7 @@ impl OfPieType {
         write_start_tag(
             writer,
             "c:ofPieType",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
