@@ -18,7 +18,7 @@ pub struct PageMargins {
 }
 impl PageMargins {
     pub fn get_bottom(&self) -> &f64 {
-        &self.bottom.get_value()
+        self.bottom.get_value()
     }
 
     pub fn set_bottom(&mut self, value: f64) -> &mut Self {
@@ -27,7 +27,7 @@ impl PageMargins {
     }
 
     pub fn get_left(&self) -> &f64 {
-        &self.left.get_value()
+        self.left.get_value()
     }
 
     pub fn set_left(&mut self, value: f64) -> &mut Self {
@@ -36,7 +36,7 @@ impl PageMargins {
     }
 
     pub fn get_right(&self) -> &f64 {
-        &self.right.get_value()
+        self.right.get_value()
     }
 
     pub fn set_right(&mut self, value: f64) -> &mut Self {
@@ -45,7 +45,7 @@ impl PageMargins {
     }
 
     pub fn get_top(&self) -> &f64 {
-        &self.top.get_value()
+        self.top.get_value()
     }
 
     pub fn set_top(&mut self, value: f64) -> &mut Self {
@@ -54,7 +54,7 @@ impl PageMargins {
     }
 
     pub fn get_header(&self) -> &f64 {
-        &self.header.get_value()
+        self.header.get_value()
     }
 
     pub fn set_header(&mut self, value: f64) -> &mut Self {
@@ -63,7 +63,7 @@ impl PageMargins {
     }
 
     pub fn get_footer(&self) -> &f64 {
-        &self.footer.get_value()
+        self.footer.get_value()
     }
 
     pub fn set_footer(&mut self, value: f64) -> &mut Self {
@@ -93,12 +93,12 @@ impl PageMargins {
             writer,
             "c:pageMargins",
             vec![
-                ("b", &self.bottom.get_value_string()),
-                ("l", &self.left.get_value_string()),
-                ("r", &self.right.get_value_string()),
-                ("t", &self.top.get_value_string()),
-                ("header", &self.header.get_value_string()),
-                ("footer", &self.footer.get_value_string()),
+                ("b", self.bottom.get_value_string()),
+                ("l", self.left.get_value_string()),
+                ("r", self.right.get_value_string()),
+                ("t", self.top.get_value_string()),
+                ("header", self.header.get_value_string()),
+                ("footer", self.footer.get_value_string()),
             ],
             true,
         );
