@@ -101,7 +101,7 @@ impl TextCharacterPropertiesType for DefaultRunProperties {
     }
 
     fn get_capital(&self) -> &TextCapsValues {
-        &self.capital.get_value()
+        self.capital.get_value()
     }
 
     fn set_capital(&mut self, value: TextCapsValues) -> &mut Self {
@@ -110,7 +110,7 @@ impl TextCharacterPropertiesType for DefaultRunProperties {
     }
 
     fn get_spacing(&self) -> &i32 {
-        &self.spacing.get_value()
+        self.spacing.get_value()
     }
 
     fn set_spacing(&mut self, value: i32) -> &mut Self {
@@ -357,10 +357,10 @@ impl DefaultRunProperties {
             Some(v) => attributes.push(("i", v)),
             None => {}
         }
-        if self.capital.has_value() == true {
+        if self.capital.has_value() {
             attributes.push(("cap", self.capital.get_value_string()));
         }
-        if self.spacing.has_value() == true {
+        if self.spacing.has_value() {
             attributes.push(("spc", self.spacing.get_value_string()));
         }
         if self.solid_fill.is_some()
