@@ -52,7 +52,7 @@ impl Run {
                     _ => (),
                 },
                 Ok(Event::Text(e)) => {
-                    self.set_text(e.unescape_and_decode(&reader).unwrap());
+                    self.set_text(e.unescape_and_decode(reader).unwrap());
                 }
                 Ok(Event::End(ref e)) => match e.name() {
                     b"a:r" => return,
