@@ -13,7 +13,7 @@ pub struct SaturationModulation {
 }
 impl SaturationModulation {
     pub fn get_val(&self) -> &i32 {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: i32) -> &mut SaturationModulation {
@@ -34,7 +34,7 @@ impl SaturationModulation {
         write_start_tag(
             writer,
             "a:satMod",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
