@@ -13,7 +13,7 @@ pub struct Shade {
 }
 impl Shade {
     pub fn get_val(&self) -> &i32 {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: i32) -> &mut Shade {
@@ -34,7 +34,7 @@ impl Shade {
         write_start_tag(
             writer,
             "a:shade",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
