@@ -28,7 +28,7 @@ pub struct TwoCellAnchor {
 }
 impl TwoCellAnchor {
     pub fn get_edit_as(&self) -> &EditAsValues {
-        &self.edit_as.get_value()
+        self.edit_as.get_value()
     }
 
     pub fn set_edit_as(&mut self, value: EditAsValues) -> &mut Self {
@@ -115,7 +115,7 @@ impl TwoCellAnchor {
     }
 
     pub fn get_is_alternate_content(&self) -> &bool {
-        &self.is_alternate_content.get_value()
+        self.is_alternate_content.get_value()
     }
 
     pub fn set_is_alternate_content(&mut self, value: bool) -> &mut Self {
@@ -123,24 +123,24 @@ impl TwoCellAnchor {
         self
     }
 
-    pub(crate) fn _adjustment_insert_row(&mut self, num_rows: &usize) {
+    pub(crate) fn _adjustment_insert_row(&mut self, num_rows: &u32) {
         self.from_marker._adjustment_insert_row(num_rows);
         self.to_marker._adjustment_insert_row(num_rows);
     }
 
-    pub(crate) fn _adjustment_insert_colmun(&mut self, num_cols: &usize) {
-        self.from_marker._adjustment_insert_colmun(num_cols);
-        self.to_marker._adjustment_insert_colmun(num_cols);
+    pub(crate) fn _adjustment_insert_column(&mut self, num_cols: &u32) {
+        self.from_marker._adjustment_insert_column(num_cols);
+        self.to_marker._adjustment_insert_column(num_cols);
     }
 
-    pub(crate) fn _adjustment_remove_row(&mut self, num_rows: &usize) {
+    pub(crate) fn _adjustment_remove_row(&mut self, num_rows: &u32) {
         self.from_marker._adjustment_remove_row(num_rows);
         self.to_marker._adjustment_remove_row(num_rows);
     }
 
-    pub(crate) fn _adjustment_remove_colmun(&mut self, num_cols: &usize) {
-        self.from_marker._adjustment_remove_colmun(num_cols);
-        self.to_marker._adjustment_remove_colmun(num_cols);
+    pub(crate) fn _adjustment_remove_column(&mut self, num_cols: &u32) {
+        self.from_marker._adjustment_remove_column(num_cols);
+        self.to_marker._adjustment_remove_column(num_cols);
     }
 
     pub(crate) fn is_support(&self) -> bool {
@@ -169,11 +169,21 @@ impl TwoCellAnchor {
         false
     }
 
+    pub(crate) fn is_image(&self) -> bool {
+        match &self.picture {
+            Some(_) => {
+                return true;
+            }
+            None => {}
+        }
+        false
+    }
+
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
         reader: &mut Reader<R>,
         e: &BytesStart,
-        drawing_relationships: &RawRelationships,
+        drawing_relationships: Option<&RawRelationships>,
     ) {
         match get_attribute(e, b"editAs") {
             Some(v) => {
@@ -194,7 +204,7 @@ impl TwoCellAnchor {
                     }
                     b"xdr:graphicFrame" => {
                         let mut obj = GraphicFrame::default();
-                        obj.set_attributes(reader, e, drawing_relationships);
+                        obj.set_attributes(reader, e, drawing_relationships.unwrap());
                         self.set_graphic_frame(obj);
                     }
                     b"xdr:sp" => {
@@ -209,7 +219,7 @@ impl TwoCellAnchor {
                     }
                     b"xdr:pic" => {
                         let mut obj = Picture::default();
-                        obj.set_attributes(reader, e, drawing_relationships);
+                        obj.set_attributes(reader, e, drawing_relationships.unwrap());
                         self.set_picture(obj);
                     }
                     _ => (),
@@ -262,7 +272,7 @@ impl TwoCellAnchor {
         // xdr:twoCellAnchor
         let mut attributes: Vec<(&str, &str)> = Vec::new();
         if &self.edit_as.has_value() == &true {
-            attributes.push(("editAs", &self.edit_as.get_value_string()));
+            attributes.push(("editAs", self.edit_as.get_value_string()));
         }
         write_start_tag(writer, "xdr:twoCellAnchor", attributes, false);
 
