@@ -11,16 +11,69 @@ use quick_xml::Writer;
 use std::io::Cursor;
 use structs::raw::RawRelationships;
 use structs::Chart;
+use structs::Image;
 use structs::OleObjects;
 use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct WorksheetDrawing {
+    image_collection: Vec<Image>,
     chart_collection: Vec<Chart>,
     one_cell_anchor_collection: Vec<OneCellAnchor>,
     two_cell_anchor_collection: Vec<TwoCellAnchor>,
 }
 impl WorksheetDrawing {
+    pub fn get_image_collection(&self) -> &Vec<Image> {
+        &self.image_collection
+    }
+
+    pub fn get_image_collection_mut(&mut self) -> &mut Vec<Image> {
+        &mut self.image_collection
+    }
+
+    pub fn add_image(&mut self, value: Image) -> &mut Self {
+        self.image_collection.push(value);
+        self
+    }
+
+    pub fn get_image(&self, col: &u32, row: &u32) -> Option<&Image> {
+        for image in &self.image_collection {
+            if image.get_col() == &(col - 1) && image.get_row() == &(row - 1) {
+                return Some(image);
+            }
+        }
+        None
+    }
+
+    pub fn get_image_mut(&mut self, col: &u32, row: &u32) -> Option<&mut Image> {
+        for image in &mut self.image_collection {
+            if image.get_col() == &(col - 1) && image.get_row() == &(row - 1) {
+                return Some(image);
+            }
+        }
+        None
+    }
+
+    pub fn get_images(&self, col: &u32, row: &u32) -> Vec<&Image> {
+        let mut result: Vec<&Image> = Vec::new();
+        for image in &self.image_collection {
+            if image.get_col() == &(col - 1) && image.get_row() == &(row - 1) {
+                result.push(image);
+            }
+        }
+        result
+    }
+
+    pub fn get_images_mut(&mut self, col: &u32, row: &u32) -> Vec<&mut Image> {
+        let mut result: Vec<&mut Image> = Vec::new();
+        for image in &mut self.image_collection {
+            if image.get_col() == &(col - 1) && image.get_row() == &(row - 1) {
+                result.push(image);
+            }
+        }
+        result
+    }
+
     pub fn get_chart_collection(&self) -> &Vec<Chart> {
         &self.chart_collection
     }
@@ -34,6 +87,44 @@ impl WorksheetDrawing {
         self
     }
 
+    pub fn get_chart(&self, col: &u32, row: &u32) -> Option<&Chart> {
+        for chart in &self.chart_collection {
+            if chart.get_col() == &(col - 1) && chart.get_row() == &(row - 1) {
+                return Some(chart);
+            }
+        }
+        None
+    }
+
+    pub fn get_chart_mut(&mut self, col: &u32, row: &u32) -> Option<&mut Chart> {
+        for chart in &mut self.chart_collection {
+            if chart.get_col() == &(col - 1) && chart.get_row() == &(row - 1) {
+                return Some(chart);
+            }
+        }
+        None
+    }
+
+    pub fn get_charts(&self, col: &u32, row: &u32) -> Vec<&Chart> {
+        let mut result: Vec<&Chart> = Vec::new();
+        for chart in &self.chart_collection {
+            if chart.get_col() == &(col - 1) && chart.get_row() == &(row - 1) {
+                result.push(chart);
+            }
+        }
+        result
+    }
+
+    pub fn get_charts_mut(&mut self, col: &u32, row: &u32) -> Vec<&mut Chart> {
+        let mut result: Vec<&mut Chart> = Vec::new();
+        for chart in &mut self.chart_collection {
+            if chart.get_col() == &(col - 1) && chart.get_row() == &(row - 1) {
+                result.push(chart);
+            }
+        }
+        result
+    }
+
     pub fn get_one_cell_anchor_collection(&self) -> &Vec<OneCellAnchor> {
         &self.one_cell_anchor_collection
     }
@@ -61,9 +152,10 @@ impl WorksheetDrawing {
     }
 
     pub fn has_drawing_object(&self) -> bool {
-        self.chart_collection.len() > 0
-            || self.one_cell_anchor_collection.len() > 0
-            || self.two_cell_anchor_collection.len() > 0
+        !self.chart_collection.is_empty()
+            || !self.image_collection.is_empty()
+            || !self.one_cell_anchor_collection.is_empty()
+            || !self.two_cell_anchor_collection.is_empty()
     }
 
     pub fn get_graphic_frame_collection(&self) -> Vec<&GraphicFrame> {
@@ -169,12 +261,71 @@ impl WorksheetDrawing {
         }
         result
     }
+    /// (This method is crate only.)
+    /// Adjustment Insert Coordinate
+    pub(crate) fn adjustment_insert_coordinate(
+        &mut self,
+        sheet_name: &str,
+        root_col_num: &u32,
+        offset_col_num: &u32,
+        root_row_num: &u32,
+        offset_row_num: &u32,
+    ) {
+        // chart
+        for graphic_frame in self.get_graphic_frame_collection_mut() {
+            for formula in graphic_frame
+                .get_graphic_mut()
+                .get_graphic_data_mut()
+                .get_chart_space_mut()
+                .get_chart_mut()
+                .get_formula_mut()
+            {
+                formula.get_address_mut().adjustment_insert_coordinate(
+                    sheet_name,
+                    root_col_num,
+                    offset_col_num,
+                    root_row_num,
+                    offset_row_num,
+                );
+            }
+        }
+    }
+
+    /// (This method is crate only.)
+    /// Adjustment Remove Coordinate
+    pub(crate) fn adjustment_remove_coordinate(
+        &mut self,
+        sheet_name: &str,
+        root_col_num: &u32,
+        offset_col_num: &u32,
+        root_row_num: &u32,
+        offset_row_num: &u32,
+    ) {
+        // chart
+        for graphic_frame in self.get_graphic_frame_collection_mut() {
+            for formula in graphic_frame
+                .get_graphic_mut()
+                .get_graphic_data_mut()
+                .get_chart_space_mut()
+                .get_chart_mut()
+                .get_formula_mut()
+            {
+                formula.get_address_mut().adjustment_remove_coordinate(
+                    sheet_name,
+                    root_col_num,
+                    offset_col_num,
+                    root_row_num,
+                    offset_row_num,
+                );
+            }
+        }
+    }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
         reader: &mut Reader<R>,
         _e: &BytesStart,
-        drawing_relationships: &RawRelationships,
+        drawing_relationships: Option<&RawRelationships>,
         ole_objects: &mut OleObjects,
     ) {
         let mut ole_index = 0;
@@ -191,8 +342,14 @@ impl WorksheetDrawing {
                             continue;
                         }
                         let mut obj = OneCellAnchor::default();
-                        obj.set_attributes(reader, e);
-                        self.add_one_cell_anchor_collection(obj);
+                        obj.set_attributes(reader, e, drawing_relationships);
+                        if obj.is_image() {
+                            let mut image = Image::default();
+                            image.set_one_cell_anchor(obj);
+                            self.add_image(image);
+                        } else {
+                            self.add_one_cell_anchor_collection(obj);
+                        }
                     }
                     b"xdr:twoCellAnchor" => {
                         if is_alternate_content {
@@ -212,6 +369,10 @@ impl WorksheetDrawing {
                                 let mut chart = Chart::default();
                                 chart.set_two_cell_anchor(obj);
                                 self.add_chart_collection(chart);
+                            } else if obj.is_image() {
+                                let mut image = Image::default();
+                                image.set_two_cell_anchor(obj);
+                                self.add_image(image);
                             } else {
                                 self.add_two_cell_anchor_collection(obj);
                             }
@@ -257,13 +418,16 @@ impl WorksheetDrawing {
         for chart in &self.chart_collection {
             chart.get_two_cell_anchor().write_to(writer, &mut r_id, &0);
         }
+        for image in &self.image_collection {
+            image.write_to(writer, &mut r_id);
+        }
         for two_cell_anchor in &self.two_cell_anchor_collection {
             two_cell_anchor.write_to(writer, &mut r_id, &0);
         }
 
         // xdr:oneCellAnchor
         for one_cell_anchor in &self.one_cell_anchor_collection {
-            one_cell_anchor.write_to(writer);
+            one_cell_anchor.write_to(writer, &mut r_id);
         }
 
         // mc:AlternateContent
