@@ -8,21 +8,21 @@ use quick_xml::Writer;
 use reader::driver::*;
 use std::io::Cursor;
 use structs::raw::RawRelationships;
-use structs::Image;
+use structs::MediaObject;
 use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct EmbeddedObjectProperties {
     prog_id: StringValue,
     shape_id: UInt32Value,
-    image: Image,
+    image: MediaObject,
     default_size: BooleanValue,
     auto_pict: BooleanValue,
     object_anchor: ObjectAnchor,
 }
 impl EmbeddedObjectProperties {
     pub fn get_prog_id(&self) -> &str {
-        &self.prog_id.get_value()
+        self.prog_id.get_value()
     }
 
     pub fn set_prog_id<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -31,7 +31,7 @@ impl EmbeddedObjectProperties {
     }
 
     pub fn get_shape_id(&self) -> &u32 {
-        &self.shape_id.get_value()
+        self.shape_id.get_value()
     }
 
     pub fn set_shape_id(&mut self, value: u32) -> &mut Self {
@@ -39,20 +39,20 @@ impl EmbeddedObjectProperties {
         self
     }
 
-    pub fn get_image(&self) -> &Image {
+    pub fn get_image(&self) -> &MediaObject {
         &self.image
     }
 
-    pub fn get_image_mut(&mut self) -> &mut Image {
+    pub fn get_image_mut(&mut self) -> &mut MediaObject {
         &mut self.image
     }
 
-    pub fn set_image(&mut self, value: Image) {
+    pub fn set_image(&mut self, value: MediaObject) {
         self.image = value;
     }
 
     pub fn get_default_size(&self) -> &bool {
-        &self.default_size.get_value()
+        self.default_size.get_value()
     }
 
     pub fn set_default_size(&mut self, value: bool) -> &mut Self {
@@ -61,7 +61,7 @@ impl EmbeddedObjectProperties {
     }
 
     pub fn get_auto_pict(&self) -> &bool {
-        &self.auto_pict.get_value()
+        self.auto_pict.get_value()
     }
 
     pub fn set_auto_pict(&mut self, value: bool) -> &mut Self {
@@ -89,7 +89,7 @@ impl EmbeddedObjectProperties {
         relationships: &RawRelationships,
     ) {
         let r_id = get_attribute(e, b"r:id").unwrap();
-        let attached_file = relationships.get_relationship_by_rid(r_id).get_raw_file();
+        let attached_file = relationships.get_relationship_by_rid(&r_id).get_raw_file();
 
         self.get_image_mut()
             .set_image_name(attached_file.get_file_name());
