@@ -12,6 +12,7 @@ use super::Strike;
 use super::Underline;
 use super::UnderlineValues;
 use super::VerticalTextAlignment;
+use md5::Digest;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -304,7 +305,7 @@ impl Font {
     pub(crate) fn get_hash_code(&self) -> String {
         format!(
             "{:x}",
-            md5::compute(format!(
+            md5::Md5::digest(format!(
                 "{}{}{}{}{}{}{}{}{}{}{}",
                 &self.font_name.val.get_hash_string(),
                 &self.font_size.val.get_hash_string(),
