@@ -14,7 +14,7 @@ pub struct FontScheme {
 }
 impl FontScheme {
     pub fn get_val(&self) -> &FontSchemeValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: FontSchemeValues) -> &mut Self {
@@ -32,9 +32,9 @@ impl FontScheme {
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // scheme
-        if self.val.has_value() == true {
+        if self.val.has_value() {
             let mut attributes: Vec<(&str, &str)> = Vec::new();
-            attributes.push(("val", &self.val.get_value_string()));
+            attributes.push(("val", self.val.get_value_string()));
             write_start_tag(writer, "scheme", attributes, true);
         }
     }
