@@ -13,7 +13,7 @@ pub struct Italic {
 }
 impl Italic {
     pub fn get_val(&self) -> &bool {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: bool) -> &mut Self {
