@@ -16,7 +16,7 @@ pub struct ObjectAnchor {
 }
 impl ObjectAnchor {
     pub fn get_move_with_cells(&self) -> &bool {
-        &self.move_with_cells.get_value()
+        self.move_with_cells.get_value()
     }
 
     pub fn set_move_with_cells(&mut self, value: bool) -> &mut Self {
@@ -55,9 +55,9 @@ impl ObjectAnchor {
         self.to_marker._adjustment_insert_row(num_rows);
     }
 
-    pub(crate) fn _adjustment_insert_colmun(&mut self, num_cols: &usize) {
-        self.from_marker._adjustment_insert_colmun(num_cols);
-        self.to_marker._adjustment_insert_colmun(num_cols);
+    pub(crate) fn _adjustment_insert_column(&mut self, num_cols: &usize) {
+        self.from_marker._adjustment_insert_column(num_cols);
+        self.to_marker._adjustment_insert_column(num_cols);
     }
 
     pub(crate) fn _adjustment_remove_row(&mut self, num_rows: &usize) {
@@ -65,9 +65,9 @@ impl ObjectAnchor {
         self.to_marker._adjustment_remove_row(num_rows);
     }
 
-    pub(crate) fn _adjustment_remove_colmun(&mut self, num_cols: &usize) {
-        self.from_marker._adjustment_remove_colmun(num_cols);
-        self.to_marker._adjustment_remove_colmun(num_cols);
+    pub(crate) fn _adjustment_remove_column(&mut self, num_cols: &usize) {
+        self.from_marker._adjustment_remove_column(num_cols);
+        self.to_marker._adjustment_remove_column(num_cols);
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
@@ -116,7 +116,7 @@ impl ObjectAnchor {
         // anchor
         let mut attributes: Vec<(&str, &str)> = Vec::new();
         if &self.move_with_cells.has_value() == &true {
-            attributes.push(("moveWithCells", &self.move_with_cells.get_value_string()));
+            attributes.push(("moveWithCells", self.move_with_cells.get_value_string()));
         }
         write_start_tag(writer, "anchor", attributes, false);
 
