@@ -2,6 +2,7 @@
 use super::Color;
 use super::EnumValue;
 use super::PatternValues;
+use md5::Digest;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -17,7 +18,7 @@ pub struct PatternFill {
 }
 impl PatternFill {
     pub fn get_pattern_type(&self) -> &PatternValues {
-        &self.pattern_type.get_value()
+        self.pattern_type.get_value()
     }
 
     pub fn set_pattern_type(&mut self, value: PatternValues) -> &mut Self {
@@ -30,10 +31,8 @@ impl PatternFill {
             if self.get_foreground_color().is_some() {
                 self.set_pattern_type(PatternValues::Solid);
             }
-        } else {
-            if self.get_foreground_color().is_none() {
-                self.set_pattern_type(PatternValues::None);
-            }
+        } else if self.get_foreground_color().is_none() {
+            self.set_pattern_type(PatternValues::None);
         }
         self
     }
@@ -78,7 +77,7 @@ impl PatternFill {
     pub(crate) fn get_hash_code(&self) -> String {
         format!(
             "{:x}",
-            md5::compute(format!(
+            md5::Md5::digest(format!(
                 "{}{}{}",
                 &self.pattern_type.get_value_string(),
                 match &self.foreground_color {
@@ -151,10 +150,10 @@ impl PatternFill {
 
         // patternFill
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        attributes.push(("patternType", &self.pattern_type.get_value_string()));
+        attributes.push(("patternType", self.pattern_type.get_value_string()));
         write_start_tag(writer, "patternFill", attributes, empty_flag);
 
-        if empty_flag == false {
+        if !empty_flag {
             // fgColor
             match &self.foreground_color {
                 Some(v) => {
