@@ -21,16 +21,22 @@ impl RawFile {
         format!("_rels/{}.rels", self.get_file_name())
     }
 
+    pub(crate) fn get_path(&self) -> String {
+        let mut v: Vec<&str> = self.get_file_target().split('/').collect();
+        v.pop();
+        v.join("/")
+    }
+
     pub(crate) fn get_extension(&self) -> String {
         let file_name = self.get_file_name();
         let v: Vec<&str> = file_name.split('.').collect();
         let extension = v.last().unwrap().clone();
-        let extension_lower = extension.to_lowercase();
-        extension_lower
+
+        extension.to_lowercase()
     }
 
     pub(crate) fn get_file_target(&self) -> &str {
-        &self.file_target.get_value()
+        self.file_target.get_value()
     }
 
     pub(crate) fn set_file_target<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -70,7 +76,7 @@ impl RawFile {
         &self,
         writer_mng: &mut WriterManager<W>,
     ) -> Result<(), XlsxError> {
-        if self.get_file_data().len() > 0 {
+        if !self.get_file_data().is_empty() {
             writer_mng.add_bin(self.get_file_target(), self.get_file_data())?;
         }
         Ok(())
