@@ -20,7 +20,7 @@ pub(crate) struct RawRelationship {
 }
 impl RawRelationship {
     pub(crate) fn get_id(&self) -> &str {
-        &self.id.get_value()
+        self.id.get_value()
     }
 
     pub(crate) fn set_id<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -29,7 +29,7 @@ impl RawRelationship {
     }
 
     pub(crate) fn get_target(&self) -> &str {
-        &self.target.get_value()
+        self.target.get_value()
     }
 
     pub(crate) fn set_target<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -38,7 +38,7 @@ impl RawRelationship {
     }
 
     pub(crate) fn get_type(&self) -> &str {
-        &self.r_type.get_value()
+        self.r_type.get_value()
     }
 
     pub(crate) fn set_type<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -60,7 +60,7 @@ impl RawRelationship {
     }
 
     pub(crate) fn get_target_mode(&self) -> &str {
-        &self.target_mode.get_value()
+        self.target_mode.get_value()
     }
 
     pub(crate) fn set_target_mode<S: Into<String>>(&mut self, value: S) -> &mut Self {
