@@ -1,4 +1,5 @@
 use super::TextElement;
+use md5::Digest;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -15,6 +16,14 @@ impl RichText {
         &self.text
     }
 
+    pub fn set_text<S: Into<String>>(&mut self, value: S) -> &mut Self {
+        self.rich_text_elements.clear();
+        let mut text_element = TextElement::default();
+        text_element.set_text(value);
+        self.add_rich_text_elements(text_element);
+        self
+    }
+
     pub fn get_rich_text_elements(&self) -> &Vec<TextElement> {
         &self.rich_text_elements
     }
@@ -48,7 +57,7 @@ impl RichText {
         for ele in &self.rich_text_elements {
             value += ele.get_hash_code().as_str();
         }
-        format!("{:x}", md5::compute(format!("{}", value)))
+        format!("{:x}", md5::Md5::digest(&value))
     }
 
     pub(crate) fn set_attributes_text<R: std::io::BufRead>(
@@ -90,7 +99,7 @@ impl RichText {
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>, tag_name: &str) {
-        if tag_name != "" {
+        if !tag_name.is_empty() {
             write_start_tag(writer, tag_name, vec![], false);
         }
 
@@ -99,7 +108,7 @@ impl RichText {
             obj.write_to(writer);
         }
 
-        if tag_name != "" {
+        if !tag_name.is_empty() {
             write_end_tag(writer, tag_name);
         }
     }
