@@ -318,7 +318,7 @@ impl RunProperties {
 
     pub(crate) fn get_hash_code(&self)-> String
     {
-        format!("{:x}", md5::compute(format!("{}{}{}{}{}{}{}{}{}{}",
+        format!("{:x}", md5::Md5::digest(format!("{}{}{}{}{}{}{}{}{}{}",
             &self.font_name.val.get_hash_string(),
             &self.font_size.val.get_hash_string(),
             &self.font_family_numbering.val.get_hash_string(),
