@@ -2,6 +2,7 @@
 use super::CellValue;
 use super::SharedStringItem;
 use super::Text;
+use hashbrown::HashMap;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -11,6 +12,7 @@ use writer::driver::*;
 #[derive(Clone, Default, Debug)]
 pub(crate) struct SharedStringTable {
     shared_string_item: Vec<SharedStringItem>,
+    map: HashMap<u64, usize>,
     regist_count: usize,
 }
 impl SharedStringTable {
@@ -28,10 +30,35 @@ impl SharedStringTable {
     }
 
     pub(crate) fn has_value(&self) -> bool {
-        self.shared_string_item.len() > 0
+        !self.shared_string_item.is_empty()
     }
 
-    pub(crate) fn set_cell(&mut self, value: &CellValue) -> u32 {
+    pub(crate) fn ensure_map(&mut self) -> bool {
+        // let l1 = self.shared_string_item.len();
+        // let l2 = self.map.len();
+        // println!("{}:::{}",l1,l2);
+        if !self.shared_string_item.is_empty() && self.map.is_empty() {
+            let mut h: HashMap<u64, usize> =
+                HashMap::with_capacity(self.shared_string_item.len());
+            for i in 0..self.shared_string_item.len() {
+                let hash = self.shared_string_item[i].get_hash_u64();
+                
+                match h.raw_entry_mut().from_key_hashed_nocheck(hash, &hash) {
+                    hashbrown::hash_map::RawEntryMut::Occupied(mut o) => {
+                        Some(o.insert(i))
+                    },
+                    hashbrown::hash_map::RawEntryMut::Vacant(v) => {
+                        v.insert(hash, i);
+                        None
+                    },
+                };
+            }
+            self.map = h;
+        }
+        true
+    }
+
+    pub(crate) fn set_cell(&mut self, value: &CellValue) -> usize {
         self.regist_count += 1;
 
         let mut shared_string_item = SharedStringItem::default();
@@ -50,16 +77,27 @@ impl SharedStringTable {
             None => {}
         }
 
-        let hash_code = shared_string_item.get_hash_code();
-        let mut id = 0;
-        for tar in &self.shared_string_item {
-            if tar.get_hash_code() == hash_code {
-                return id;
-            }
-            id += 1;
+        let hash_code = shared_string_item.get_hash_u64();
+        self.ensure_map();
+
+        let mut is_new = false;
+        let n = match self.map.raw_entry_mut().from_key_hashed_nocheck(hash_code, &hash_code) {
+            hashbrown::hash_map::RawEntryMut::Occupied(o) => {
+                o.get().to_owned()
+            },
+            hashbrown::hash_map::RawEntryMut::Vacant(v) => {
+                let n = self.shared_string_item.len();
+                is_new =true;
+                v.insert(hash_code, n);
+                n
+            },
+        };
+
+        if is_new {
+            self.set_shared_string_item(shared_string_item);
         }
-        self.set_shared_string_item(shared_string_item);
-        return id;
+
+        n
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
