@@ -1,10 +1,11 @@
 use helper::address::*;
 use helper::coordinate::*;
 use reader::xlsx::*;
+use std::sync::Arc;
+use std::sync::RwLock;
 use structs::Address;
 use structs::Calculation;
 use structs::CellValue;
-use structs::Image;
 use structs::Properties;
 use structs::Security;
 use structs::SharedStringTable;
@@ -36,14 +37,15 @@ pub struct Spreadsheet {
     tab_ratio: i32,
     theme: Theme,
     stylesheet: Stylesheet,
-    shared_string_table: SharedStringTable,
+    shared_string_table: Arc<RwLock<SharedStringTable>>,
     workbook_view: WorkbookView,
+    backup_context_types: Vec<(String, String)>,
+    pivot_caches: Vec<(String, String, String)>,
 }
 impl Spreadsheet {
     // ************************
     // update Coordinate
     // ************************
-
     /// Insert new rows.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
@@ -54,16 +56,11 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_row("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_row<S: Into<String>>(
-        &mut self,
-        sheet_name: S,
-        row_index: u32,
-        num_rows: u32,
-    ) {
-        self.adjustment_insert_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
+    pub fn insert_new_row(&mut self, sheet_name: &str, row_index: &u32, num_rows: &u32) {
+        self.adjustment_insert_coordinate(sheet_name, &0, &0, row_index, num_rows);
     }
 
-    /// Insert new colmuns.
+    /// Insert new columns.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
     /// * `column` - Specify point of insert. ex) "B"
@@ -71,20 +68,15 @@ impl Spreadsheet {
     /// # Examples
     /// ```
     /// let mut book = umya_spreadsheet::new_file();
-    /// book.insert_new_colmun("Sheet1", "B", 3);
+    /// book.insert_new_column("Sheet1", "B", 3);
     /// ```
-    pub fn insert_new_colmun<S: Into<String>>(
-        &mut self,
-        sheet_name: S,
-        column: S,
-        num_columns: u32,
-    ) {
-        let column_upper = column.into().to_uppercase();
+    pub fn insert_new_column(&mut self, sheet_name: &str, column: &str, num_columns: &u32) {
+        let column_upper = column.to_uppercase();
         let column_index = column_index_from_string(column_upper);
-        self.insert_new_colmun_by_index(&sheet_name.into(), column_index, num_columns);
+        self.insert_new_column_by_index(sheet_name, &column_index, num_columns);
     }
 
-    /// Insert new colmuns.
+    /// Insert new columns.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
     /// * `column_index` - Specify point of insert. ex) 2
@@ -92,32 +84,32 @@ impl Spreadsheet {
     /// # Examples
     /// ```
     /// let mut book = umya_spreadsheet::new_file();
-    /// book.insert_new_colmun_by_index("Sheet1", 2, 3);
+    /// book.insert_new_column_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_colmun_by_index<S: Into<String>>(
+    pub fn insert_new_column_by_index(
         &mut self,
-        sheet_name: S,
-        column_index: u32,
-        num_columns: u32,
+        sheet_name: &str,
+        column_index: &u32,
+        num_columns: &u32,
     ) {
-        self.adjustment_insert_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
+        self.adjustment_insert_coordinate(sheet_name, column_index, num_columns, &0, &0);
     }
 
     /// Remove rows.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
-    /// * `row_index` - Specify point of remove. ex) 1
-    /// * `num_rows` - Specify number to remove. ex) 2
+    /// * `row_index` - Specify point of remove. ex) &1
+    /// * `num_rows` - Specify number to remove. ex) &2
     /// # Examples
     /// ```
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_row("Sheet1", 2, 3);
     /// ```
-    pub fn remove_row<S: Into<String>>(&mut self, sheet_name: S, row_index: u32, num_rows: u32) {
-        self.adjustment_remove_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
+    pub fn remove_row(&mut self, sheet_name: &str, row_index: &u32, num_rows: &u32) {
+        self.adjustment_remove_coordinate(sheet_name, &0, &0, row_index, num_rows);
     }
 
-    /// Remove colmuns.
+    /// Remove columns.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
     /// * `column` - Specify point of remove. ex) "B"
@@ -125,15 +117,15 @@ impl Spreadsheet {
     /// # Examples
     /// ```
     /// let mut book = umya_spreadsheet::new_file();
-    /// book.remove_colmun("Sheet1", "B", 3);
+    /// book.remove_column("Sheet1", "B", 3);
     /// ```
-    pub fn remove_colmun<S: Into<String>>(&mut self, sheet_name: S, column: S, num_columns: u32) {
-        let column_upper = column.into().to_uppercase();
+    pub fn remove_column(&mut self, sheet_name: &str, column: &str, num_columns: &u32) {
+        let column_upper = column.to_uppercase();
         let column_index = column_index_from_string(column_upper);
-        self.remove_colmun_by_index(&sheet_name.into(), column_index, num_columns);
+        self.remove_column_by_index(sheet_name, &column_index, num_columns);
     }
 
-    /// Remove colmuns.
+    /// Remove columns.
     /// # Arguments
     /// * `sheet_name` - Specify the sheet name. ex) "Sheet1"
     /// * `column_index` - Specify point of remove. ex) 2
@@ -141,15 +133,15 @@ impl Spreadsheet {
     /// # Examples
     /// ```
     /// let mut book = umya_spreadsheet::new_file();
-    /// book.remove_colmun_by_index("Sheet1", 2, 3);
+    /// book.remove_column_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn remove_colmun_by_index<S: Into<String>>(
+    pub fn remove_column_by_index(
         &mut self,
-        sheet_name: S,
-        column_index: u32,
-        num_columns: u32,
+        sheet_name: &str,
+        column_index: &u32,
+        num_columns: &u32,
     ) {
-        self.adjustment_remove_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
+        self.adjustment_remove_coordinate(sheet_name, column_index, num_columns, &0, &0);
     }
 
     /// (This method is crate only.)
@@ -164,7 +156,8 @@ impl Spreadsheet {
     ) {
         self.read_sheet_collection();
         for worksheet in &mut self.work_sheet_collection {
-            worksheet.adjustment_insert_coordinate(
+            worksheet.adjustment_insert_coordinate(column_index, num_columns, row_index, num_rows);
+            worksheet.adjustment_insert_coordinate_from_other_sheet(
                 sheet_name,
                 column_index,
                 num_columns,
@@ -186,7 +179,8 @@ impl Spreadsheet {
     ) {
         self.read_sheet_collection();
         for worksheet in &mut self.work_sheet_collection {
-            worksheet.adjustment_remove_coordinate(
+            worksheet.adjustment_remove_coordinate(column_index, num_columns, row_index, num_rows);
+            worksheet.adjustment_remove_coordinate_from_other_sheet(
                 sheet_name,
                 column_index,
                 num_columns,
@@ -206,11 +200,11 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// let mut cell_value_List = book.get_cell_value_by_address("Sheet1!A1:C5");
     /// ```
-    pub fn get_cell_value_by_address<S: Into<String>>(&self, address: S) -> Vec<&CellValue> {
+    pub fn get_cell_value_by_address(&self, address: &str) -> Vec<&CellValue> {
         let (sheet_name, range) = split_address(address);
-        self.get_sheet_by_name(sheet_name)
+        self.get_sheet_by_name(&sheet_name)
             .unwrap()
-            .get_cell_value_by_range(range)
+            .get_cell_value_by_range(&range)
     }
 
     /// (This method is crate only.)
@@ -222,7 +216,7 @@ impl Spreadsheet {
     pub(crate) fn get_cell_value_by_address_crate(&self, address: &Address) -> Vec<&CellValue> {
         self.get_sheet_by_name(address.get_sheet_name())
             .unwrap()
-            .get_cell_value_by_range(address.get_range().get_range())
+            .get_cell_value_by_range(&address.get_range().get_range())
     }
 
     /// Get Theme.
@@ -329,8 +323,8 @@ impl Spreadsheet {
 
     /// (This method is crate only.)
     /// Get Shared String Table.
-    pub(crate) fn get_shared_string_table(&self) -> &SharedStringTable {
-        &self.shared_string_table
+    pub(crate) fn get_shared_string_table(&self) -> Arc<RwLock<SharedStringTable>> {
+        self.shared_string_table.clone()
     }
 
     /// (This method is crate only.)
@@ -338,14 +332,14 @@ impl Spreadsheet {
     /// # Arguments
     /// * `value` - Shared String Table
     pub(crate) fn set_shared_string_table(&mut self, value: SharedStringTable) -> &mut Self {
-        self.shared_string_table = value;
+        self.shared_string_table = Arc::new(RwLock::new(value));
         self
     }
 
     /// Get Work Sheet List.
     pub fn get_sheet_collection(&self) -> &Vec<Worksheet> {
         for worksheet in &self.work_sheet_collection {
-            if worksheet.is_serialized() == false {
+            if !worksheet.is_serialized() {
                 panic!("This Worksheet is Not Serialized. Please exec to read_sheet(&mut self, index: usize);");
             }
         }
@@ -374,10 +368,15 @@ impl Spreadsheet {
     /// serialize by all worksheet.
     pub fn read_sheet_collection(&mut self) -> &mut Self {
         let theme = self.get_theme().clone();
-        let shared_string_table = self.get_shared_string_table().clone();
+        let shared_string_table = self.get_shared_string_table();
         let stylesheet = self.get_stylesheet().clone();
         for worksheet in &mut self.work_sheet_collection {
-            raw_to_serialize_by_worksheet(worksheet, &theme, &shared_string_table, &stylesheet);
+            raw_to_serialize_by_worksheet(
+                worksheet,
+                &theme,
+                shared_string_table.clone(),
+                &stylesheet,
+            );
         }
         self
     }
@@ -385,13 +384,27 @@ impl Spreadsheet {
     /// serialize a worksheet.
     pub fn read_sheet(&mut self, index: usize) -> &mut Self {
         let theme = self.get_theme().clone();
-        let shared_string_table = self.get_shared_string_table().clone();
+        let shared_string_table = self.get_shared_string_table();
         let stylesheet = self.get_stylesheet().clone();
         let worksheet = self.work_sheet_collection.get_mut(index).unwrap();
-        raw_to_serialize_by_worksheet(worksheet, &theme, &shared_string_table, &stylesheet);
+        raw_to_serialize_by_worksheet(worksheet, &theme, shared_string_table, &stylesheet);
         self
     }
 
+    pub(crate) fn find_sheeet_index_by_name(
+        &self,
+        sheet_name: &str,
+    ) -> Result<usize, &'static str> {
+        let mut result = 0;
+        for sheet in &self.work_sheet_collection {
+            if sheet.get_name() == sheet_name {
+                return Ok(result);
+            }
+            result += 1;
+        }
+        Err("not found.")
+    }
+
     /// Get Work Sheet.
     /// # Arguments
     /// * `index` - sheet index
@@ -400,70 +413,87 @@ impl Spreadsheet {
     pub fn get_sheet(&self, index: usize) -> Result<&Worksheet, &'static str> {
         match self.work_sheet_collection.get(index) {
             Some(v) => {
-                if v.is_serialized() == false {
+                if !v.is_serialized() {
                     panic!("This Worksheet is Not Serialized. Please exec to read_sheet(&mut self, index: usize);");
                 }
+                Ok(v)
+            }
+            None => Err("Not found."),
+        }
+    }
+
+    /// Get Work Sheet.
+    /// # Arguments
+    /// * `sheet_name` - sheet name
+    /// # Return value
+    /// * `Result<&Worksheet, &'static str>` - OK:work sheet. Err:Error.
+    pub fn get_sheet_by_name(&self, sheet_name: &str) -> Result<&Worksheet, &'static str> {
+        match self.find_sheeet_index_by_name(sheet_name) {
+            Ok(index) => {
+                return self.get_sheet(index);
+            }
+            Err(e) => {
+                return Err(e);
+            }
+        }
+    }
+
+    /// Get Work Sheet in mutable.
+    /// # Arguments
+    /// * `index` - sheet index
+    /// # Return value
+    /// * `Result<&mut Worksheet, &'static str>` - OK:work sheet. Err:Error.
+    pub fn get_sheet_mut(&mut self, index: usize) -> Result<&mut Worksheet, &'static str> {
+        let theme = self.get_theme().clone();
+        let shared_string_table = self.get_shared_string_table();
+        let stylesheet = self.get_stylesheet().clone();
+        match self.work_sheet_collection.get_mut(index) {
+            Some(v) => {
+                raw_to_serialize_by_worksheet(v, &theme, shared_string_table, &stylesheet);
                 return Ok(v);
             }
             None => return Err("Not found."),
         }
     }
 
-    /// Get Work Sheet in mutable.
-    /// # Arguments
-    /// * `index` - sheet index
-    /// # Return value
-    /// * `&mut Worksheet` - Work sheet.
-    pub fn get_sheet_mut(&mut self, index: usize) -> &mut Worksheet {
-        let theme = self.get_theme().clone();
-        let shared_string_table = self.get_shared_string_table().clone();
-        let stylesheet = self.get_stylesheet().clone();
-        let worksheet = self.work_sheet_collection.get_mut(index).unwrap();
-        raw_to_serialize_by_worksheet(worksheet, &theme, &shared_string_table, &stylesheet);
-        worksheet
-    }
-
-    /// Get Work Sheet.
-    /// # Arguments
-    /// * `sheet_name` - sheet name
-    /// # Return value
-    /// * `Result<&Worksheet, &'static str>` - OK:work sheet. Err:Error.
-    pub fn get_sheet_by_name<S: Into<String>>(
-        &self,
-        sheet_name: S,
-    ) -> Result<&Worksheet, &'static str> {
-        let v = sheet_name.into();
-        for sheet in &self.work_sheet_collection {
-            if sheet.get_title() == &v {
-                if sheet.is_serialized() == false {
-                    panic!("This Worksheet is Not Serialized. Please exec to read_sheet(&mut self, index: usize);");
-                }
-                return Ok(sheet);
-            }
-        }
-        Err("not found.")
-    }
-
     /// Get Work Sheet in mutable.
     /// # Arguments
     /// * `sheet_name` - sheet name
     /// # Return value
     /// * `Result<&mut Worksheet, &'static str>` - OK:work sheet. Err:Error.
-    pub fn get_sheet_by_name_mut<S: Into<String>>(
+    pub fn get_sheet_by_name_mut(
         &mut self,
-        sheet_name: S,
+        sheet_name: &str,
     ) -> Result<&mut Worksheet, &'static str> {
-        let theme = self.get_theme().clone();
-        let shared_string_table = self.get_shared_string_table().clone();
-        let stylesheet = self.get_stylesheet().clone();
-        let v = sheet_name.into();
-        for worksheet in &mut self.work_sheet_collection {
-            if worksheet.get_title() == &v {
-                raw_to_serialize_by_worksheet(worksheet, &theme, &shared_string_table, &stylesheet);
-                return Ok(worksheet);
+        match self.find_sheeet_index_by_name(sheet_name) {
+            Ok(index) => {
+                return self.get_sheet_mut(index);
+            }
+            Err(e) => {
+                return Err(e);
             }
         }
-        Err("not found.")
+    }
+
+    pub fn set_active_sheet(&mut self, index: u32) -> &mut Self {
+        self.get_workbook_view_mut().set_active_tab(index);
+        self
+    }
+
+    /// Get Active Work Sheet.
+    /// # Return value
+    /// * `&Worksheet` - Work sheet.
+    pub fn get_active_sheet(&self) -> &Worksheet {
+        let index = self.get_workbook_view().get_active_tab().clone();
+        self.get_sheet(index as usize).unwrap()
+    }
+
+    /// Get Active Work Sheet in mutable.
+    /// # Return value
+    /// * `&mut Worksheet` - Work sheet.
+    pub fn get_active_sheet_mut(&mut self) -> &mut Worksheet {
+        let index = self.get_workbook_view().get_active_tab().clone();
+        self.get_sheet_mut(index as usize).unwrap()
     }
 
     /// Add Work Sheet.
@@ -472,8 +502,8 @@ impl Spreadsheet {
     /// # Return value
     /// * `Result<&mut Worksheet, &'static str>` - OK:added work sheet. Err:Error.
     pub fn add_sheet(&mut self, value: Worksheet) -> Result<&mut Worksheet, &'static str> {
-        let title = value.get_title();
-        match Spreadsheet::check_sheet_title(self, title) {
+        let title = value.get_name();
+        match Spreadsheet::check_sheet_name(self, title) {
             Ok(_) => {}
             Err(e) => return Err(e),
         }
@@ -481,6 +511,35 @@ impl Spreadsheet {
         Ok(self.work_sheet_collection.last_mut().unwrap())
     }
 
+    /// Remove Work Sheet.
+    /// # Arguments
+    /// * `index` - sheet index
+    /// # Return value
+    /// * `Result<(), &'static str>` - OK:removed worksheet. Err:Error.
+    pub fn remove_sheet(&mut self, index: usize) -> Result<(), &'static str> {
+        if self.work_sheet_collection.len() <= index {
+            return Err("out of index.");
+        }
+        self.work_sheet_collection.remove(index);
+        Ok(())
+    }
+
+    /// Remove Work Sheet.
+    /// # Arguments
+    /// * `sheet_name` - sheet name
+    /// # Return value
+    /// * `Result<(), &'static str>` - OK:removed worksheet. Err:Error.
+    pub fn remove_sheet_by_name(&mut self, sheet_name: &str) -> Result<(), &'static str> {
+        let cnt_before = self.work_sheet_collection.len();
+        self.work_sheet_collection
+            .retain(|x| !(x.get_name() == sheet_name));
+        let cnt_after = self.work_sheet_collection.len();
+        if cnt_before == cnt_after {
+            return Err("out of index.");
+        }
+        Ok(())
+    }
+
     /// Add New Work Sheet.
     /// # Arguments
     /// * `sheet_title` - sheet title
@@ -491,7 +550,7 @@ impl Spreadsheet {
         sheet_title: S,
     ) -> Result<&mut Worksheet, &'static str> {
         let v = sheet_title.into();
-        match Spreadsheet::check_sheet_title(self, &v) {
+        match Spreadsheet::check_sheet_name(self, &v) {
             Ok(_) => {}
             Err(e) => return Err(e),
         }
@@ -513,47 +572,42 @@ impl Spreadsheet {
     ) -> &mut Worksheet {
         let mut worksheet = Worksheet::default();
         worksheet.set_sheet_id(sheet_id);
-        worksheet.set_title(sheet_title.into());
+        worksheet.set_name(sheet_title.into());
         self.work_sheet_collection.push(worksheet);
         self.work_sheet_collection.last_mut().unwrap()
     }
 
-    /// Set Sheet Title.
+    /// Set Sheet Name.
     /// # Arguments
     /// * `index` - target sheet index
-    /// * `sheet_title` - sheet title
+    /// * `sheet_name` - sheet name
     /// # Return value
     /// * `Result<(), &'static str>` - OK:Success  Err:Error.
-    pub fn set_sheet_title<S: Into<String>>(
+    pub fn set_sheet_name<S: Into<String>>(
         &mut self,
         index: usize,
-        sheet_title: S,
+        sheet_name: S,
     ) -> Result<(), &'static str> {
-        let v = sheet_title.into();
-        match Spreadsheet::check_sheet_title(self, &v) {
+        let sheet_name_str = sheet_name.into();
+        match Spreadsheet::check_sheet_name(self, sheet_name_str.as_ref()) {
             Ok(_) => {}
             Err(e) => return Err(e),
         }
         match self.work_sheet_collection.get_mut(index) {
             Some(sheet) => {
-                sheet.set_title(v);
+                sheet.set_name(sheet_name_str);
                 Ok(())
             }
-            None => return Err("sheet not found."),
+            None => Err("sheet not found."),
         }
     }
 
     /// (This method is crate only.)
-    /// Check for duplicate sheet title.
-    /// # Arguments
-    /// * `value` - sheet title
-    /// # Return value
-    /// * `Result<(), &'static str>` - OK:Not duplicate Err:Duplicate.
-    pub(crate) fn check_sheet_title<S: Into<String>>(&self, value: S) -> Result<(), &'static str> {
-        let v = value.into();
+    /// Check for duplicate sheet name.
+    pub(crate) fn check_sheet_name(&self, value: &str) -> Result<(), &'static str> {
         for work_sheet in &self.work_sheet_collection {
-            if &v == work_sheet.get_title() {
-                return Err("title duplicate.");
+            if value == work_sheet.get_name() {
+                return Err("name duplicate.");
             }
         }
         Ok(())
@@ -594,24 +648,53 @@ impl Spreadsheet {
         false
     }
 
-    /// Outputs all images contained in the spreadsheet.
-    /// # Return value
-    /// * `Vec<&Image>` - Image Object List.
-    pub fn get_image_collection(&self) -> Vec<&Image> {
-        let mut result: Vec<&Image> = Vec::new();
-        for worksheet in self.get_sheet_collection_no_check() {
-            for image in worksheet.get_image_collection() {
-                let mut is_new = true;
-                for v in &result {
-                    if v.get_image_name() == image.get_image_name() {
-                        is_new = false;
+    pub(crate) fn get_backup_context_types(&self) -> &Vec<(String, String)> {
+        &self.backup_context_types
+    }
+
+    pub(crate) fn set_backup_context_types(&mut self, value: Vec<(String, String)>) -> &mut Self {
+        self.backup_context_types = value;
+        self
+    }
+
+    pub(crate) fn get_pivot_caches(&self) -> Vec<(String, String, String)> {
+        let mut result: Vec<(String, String, String)> = Vec::new();
+        for (val1, val2, val3) in &self.pivot_caches {
+            for worksheet in self.get_sheet_collection_no_check() {
+                for pivot_cache_definition in worksheet.get_pivot_cache_definition_collection() {
+                    let val3_up = format!("xl/{}", val3);
+                    if val3_up.as_str() == pivot_cache_definition {
+                        let mut is_new = true;
+                        for (_, _, r_val3) in &result {
+                            if r_val3 == val3 {
+                                is_new = false;
+                            }
+                        }
+                        if is_new {
+                            result.push((val1.clone(), val2.clone(), val3.clone()));
+                        }
                     }
                 }
-                if is_new {
-                    result.push(image);
-                }
             }
         }
         result
     }
+
+    pub(crate) fn add_pivot_caches(&mut self, value: (String, String, String)) -> &mut Self {
+        self.pivot_caches.push(value);
+        self
+    }
+
+    pub(crate) fn update_pivot_caches(&mut self, key: String, value: String) -> &mut Self {
+        let mut result: Vec<(String, String, String)> = Vec::new();
+        for (val1, val2, val3) in &self.pivot_caches {
+            let mut result_value = value.clone();
+            if val1 != &key {
+                result_value = val3.clone();
+            }
+            result.push((val1.clone(), val2.clone(), result_value));
+        }
+        self.pivot_caches = result;
+        self
+    }
 }
