@@ -1,6 +1,7 @@
 // r
 use super::Font;
 use super::Text;
+use md5::Digest;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -14,7 +15,7 @@ pub struct TextElement {
 }
 impl TextElement {
     pub fn get_text(&self) -> &str {
-        &self.text.get_value()
+        self.text.get_value()
     }
 
     pub fn set_text<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -45,7 +46,7 @@ impl TextElement {
     }
 
     pub fn get_font(&self) -> &Option<Font> {
-        &self.get_run_properties()
+        self.get_run_properties()
     }
 
     pub fn get_font_mut(&mut self) -> &mut Font {
@@ -59,7 +60,7 @@ impl TextElement {
     pub(crate) fn get_hash_code(&self) -> String {
         format!(
             "{:x}",
-            md5::compute(format!(
+            md5::Md5::digest(format!(
                 "{}{}",
                 &self.text.get_value(),
                 match &self.run_properties {
