@@ -77,7 +77,7 @@ impl Anchor {
     }
 
     pub fn set_bottom_offset(&mut self, value: u32) {
-        self.bottom_offset = value.into();
+        self.bottom_offset = value;
     }
 
     pub(crate) fn adjustment_insert_row(&mut self, num_rows: &u32) {
@@ -85,7 +85,7 @@ impl Anchor {
         self.bottom_row += num_rows;
     }
 
-    pub(crate) fn adjustment_insert_colmun(&mut self, num_cols: &u32) {
+    pub(crate) fn adjustment_insert_column(&mut self, num_cols: &u32) {
         self.left_column += num_cols;
         self.right_column += num_cols;
     }
@@ -103,7 +103,7 @@ impl Anchor {
         };
     }
 
-    pub(crate) fn adjustment_remove_colmun(&mut self, num_cols: &u32) {
+    pub(crate) fn adjustment_remove_column(&mut self, num_cols: &u32) {
         self.left_column = if &self.left_column > num_cols {
             self.left_column - num_cols
         } else {
@@ -125,7 +125,7 @@ impl Anchor {
         loop {
             match reader.read_event(&mut buf) {
                 Ok(Event::Text(e)) => {
-                    let text = e.unescape_and_decode(&reader).unwrap();
+                    let text = e.unescape_and_decode(reader).unwrap();
                     let split_str: Vec<&str> = text.split(", ").collect();
                     self.set_left_column(
                         split_str
