@@ -1,6 +1,7 @@
 use quick_xml::Writer;
 use std::io;
 use std::io::Cursor;
+use structs::Spreadsheet;
 use writer::driver::*;
 use writer::xlsx::XlsxError;
 
@@ -12,7 +13,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
     pub fn new(arv: zip::ZipWriter<W>) -> Self {
         WriterManager {
             files: Vec::new(),
-            arv: arv,
+            arv,
         }
     }
 
@@ -22,7 +23,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
         writer: Writer<Cursor<Vec<u8>>>,
     ) -> Result<(), XlsxError> {
         let is_match = self.check_file_exist(target);
-        if is_match == false {
+        if !is_match {
             make_file_from_writer(target, &mut self.arv, writer, None)?;
             self.files.push(target.to_string());
         }
@@ -31,7 +32,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
 
     pub(crate) fn add_bin(&mut self, target: &str, data: &Vec<u8>) -> Result<(), XlsxError> {
         let is_match = self.check_file_exist(target);
-        if is_match == false {
+        if !is_match {
             make_file_from_bin(target, &mut self.arv, data, None)?;
             self.files.push(target.to_string());
         }
@@ -47,10 +48,6 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
         self
     }
 
-    pub(crate) fn _get_file_list(&self) -> &Vec<String> {
-        &self.files
-    }
-
     pub(crate) fn check_file_exist(&mut self, file_path: &str) -> bool {
         self.file_list_sort();
         for file in &self.files {
@@ -70,8 +67,8 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/drawings/drawing{}.xml", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
-                self.add_writer(&file_path, writer);
+            if !is_match {
+                self.add_writer(&file_path, writer)?;
                 return Ok(index);
             }
         }
@@ -86,7 +83,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/drawings/vmlDrawing{}.vml", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_writer(&file_path, writer)?;
                 return Ok(index);
             }
@@ -102,7 +99,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/comments{}.xml", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_writer(&file_path, writer)?;
                 return Ok(index);
             }
@@ -118,7 +115,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/charts/chart{}.xml", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_writer(&file_path, writer)?;
                 return Ok(index);
             }
@@ -131,7 +128,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/embeddings/oleObject{}.bin", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_bin(&file_path, writer)?;
                 return Ok(index);
             }
@@ -144,7 +141,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/embeddings/Microsoft_Excel_Worksheet{}.xlsx", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_bin(&file_path, writer)?;
                 return Ok(index);
             }
@@ -159,7 +156,7 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
             index += 1;
             let file_path = format!("xl/printerSettings/printerSettings{}.bin", index);
             let is_match = self.check_file_exist(&file_path);
-            if is_match == false {
+            if !is_match {
                 self.add_bin(&file_path, writer)?;
                 return Ok(index);
             }
@@ -176,13 +173,98 @@ impl<W: io::Seek + io::Write> WriterManager<W> {
         false
     }
 
-    pub(crate) fn has_find(&self, find_str: &str) -> Vec<String> {
-        let mut result: Vec<String> = Vec::new();
+    pub(crate) fn make_context_type_override(
+        &mut self,
+        spreadsheet: &Spreadsheet,
+    ) -> Vec<(String, String)> {
+        self.file_list_sort();
+        let mut list: Vec<(String, String)> = Vec::new();
         for file in &self.files {
-            if file.starts_with(find_str) {
-                result.push(format!("/{}", file));
+            let file = format!("/{}", file);
+            let mut content_type = "";
+            // Override workbook
+            if file.starts_with("/xl/workbook.xml") {
+                content_type = match spreadsheet.get_has_macros() {
+                    true => "application/vnd.ms-excel.sheet.macroEnabled.main+xml",
+                    false => {
+                        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml"
+                    }
+                };
+            }
+
+            // Override sheet
+            if file.starts_with("/xl/worksheets/sheet") {
+                content_type =
+                    "application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml";
+            }
+
+            // Override comments
+            if file.starts_with("/xl/comments") {
+                content_type =
+                    "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml";
+            }
+
+            // Override theme
+            if file.starts_with("/xl/theme/theme") {
+                content_type = "application/vnd.openxmlformats-officedocument.theme+xml";
+            }
+
+            // Override styles
+            if file.starts_with("/xl/styles.xml") {
+                content_type =
+                    "application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml";
+            }
+
+            // Override sharedStrings
+            if file.starts_with("/xl/sharedStrings.xml") {
+                content_type =
+                    "application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml";
+            }
+
+            // Override drawing
+            if file.starts_with("/xl/drawings/drawing") {
+                content_type = "application/vnd.openxmlformats-officedocument.drawing+xml";
+            }
+
+            // Override chart
+            if file.starts_with("/xl/charts/chart") {
+                content_type = "application/vnd.openxmlformats-officedocument.drawingml.chart+xml";
+            }
+
+            // Override embeddings
+            if file.starts_with("/xl/embeddings/oleObject") {
+                content_type = "application/vnd.openxmlformats-officedocument.oleObject";
+            }
+
+            // Override xl/vbaProject.bin
+            if file.starts_with("/xl/vbaProject.bin") {
+                content_type = "application/vnd.ms-office.vbaProject";
+            }
+
+            // Override docProps/core
+            if file.starts_with("/docProps/core.xml") {
+                content_type = "application/vnd.openxmlformats-package.core-properties+xml";
+            }
+
+            // Override docProps/app
+            if file.starts_with("/docProps/app.xml") {
+                content_type =
+                    "application/vnd.openxmlformats-officedocument.extended-properties+xml";
+            }
+
+            // Override Unsupported
+            if content_type.is_empty() {
+                for (old_part_name, old_content_type) in spreadsheet.get_backup_context_types() {
+                    if old_part_name == &file {
+                        content_type = old_content_type;
+                    }
+                }
+            }
+
+            if !content_type.is_empty() {
+                list.push((file, content_type.to_string()));
             }
         }
-        result
+        list
     }
 }
