@@ -5,12 +5,11 @@ use std::io;
 use super::driver::*;
 use super::XlsxError;
 use structs::Spreadsheet;
+use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     spreadsheet: &Spreadsheet,
-    arv: &mut zip::ZipWriter<W>,
-    sub_dir: &str,
-    file_name: &str,
+    writer_mng: &mut WriterManager<W>,
 ) -> Result<(), XlsxError> {
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
@@ -108,7 +107,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     for workseet in spreadsheet.get_sheet_collection_no_check() {
         // vt:lpstr
         write_start_tag(&mut writer, "vt:lpstr", vec![], false);
-        write_text_node(&mut writer, workseet.get_title());
+        write_text_node(&mut writer, workseet.get_name());
         write_end_tag(&mut writer, "vt:lpstr");
     }
 
@@ -147,6 +146,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     write_end_tag(&mut writer, "AppVersion");
 
     write_end_tag(&mut writer, "Properties");
-    let _ = make_file_from_writer(&file_name, arv, writer, Some(sub_dir)).unwrap();
-    Ok(())
+
+    let target = "docProps/app.xml";
+    writer_mng.add_writer(target, writer)
 }
