@@ -4,15 +4,21 @@ use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
 use std::io;
 use std::result;
+use std::sync::Arc;
+use std::sync::RwLock;
 use structs::SharedStringTable;
-
-const SHARED_STRINGS: &'static str = "sharedStrings.xml";
+use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
-    shared_string_table: &SharedStringTable,
-    arv: &mut zip::ZipWriter<W>,
+    shared_string_table: Arc<RwLock<SharedStringTable>>,
+    writer_mng: &mut WriterManager<W>,
 ) -> result::Result<(), XlsxError> {
-    if shared_string_table.get_shared_string_item().len() == 0 {
+    if shared_string_table
+        .read()
+        .unwrap()
+        .get_shared_string_item()
+        .is_empty()
+    {
         return Ok(());
     }
 
@@ -25,8 +31,8 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     )));
     write_new_line(&mut writer);
 
-    shared_string_table.write_to(&mut writer);
+    shared_string_table.write().unwrap().write_to(&mut writer);
 
-    let _ = make_file_from_writer(SHARED_STRINGS, arv, writer, Some("xl"))?;
-    Ok(())
+    let target = "xl/sharedStrings.xml";
+    writer_mng.add_writer(target, writer)
 }
