@@ -4,13 +4,11 @@ use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
 use std::io;
 use structs::Stylesheet;
-
-const SUB_DIR: &'static str = "xl";
-const FILE_NAME: &'static str = "styles.xml";
+use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     stylesheet: &Stylesheet,
-    arv: &mut zip::ZipWriter<W>,
+    writer_mng: &mut WriterManager<W>,
 ) -> Result<(), XlsxError> {
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
@@ -23,6 +21,6 @@ pub(crate) fn write<W: io::Seek + io::Write>(
 
     stylesheet.write_to(&mut writer);
 
-    let _ = make_file_from_writer(FILE_NAME, arv, writer, Some(SUB_DIR)).unwrap();
-    Ok(())
+    let target = "xl/styles.xml";
+    writer_mng.add_writer(target, writer)
 }
