@@ -3,6 +3,8 @@ use super::XlsxError;
 use quick_xml::events::{BytesDecl, Event};
 use quick_xml::Writer;
 use std::io;
+use std::sync::Arc;
+use std::sync::RwLock;
 use structs::Cell;
 use structs::SharedStringTable;
 use structs::Stylesheet;
@@ -12,7 +14,7 @@ use structs::WriterManager;
 pub(crate) fn write<W: io::Seek + io::Write>(
     sheet_no: &i32,
     worksheet: &Worksheet,
-    shared_string_table: &mut SharedStringTable,
+    shared_string_table: Arc<RwLock<SharedStringTable>>,
     stylesheet: &mut Stylesheet,
     has_macros: bool,
     writer_mng: &mut WriterManager<W>,
@@ -68,7 +70,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             true => {
                 let code_name = match worksheet.has_code_name() {
                     true => worksheet.get_code_name().as_ref().unwrap(),
-                    false => worksheet.get_title(),
+                    false => worksheet.get_name(),
                 };
                 attributes.push(("codeName", code_name));
             }
@@ -83,7 +85,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
                 write_end_tag(&mut writer, "sheetPr");
             }
             None => {
-                if attributes.len() > 0 {
+                if !attributes.is_empty() {
                     write_start_tag(&mut writer, "sheetPr", attributes, true);
                 }
             }
@@ -123,14 +125,16 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         column_dimensions.write_to(&mut writer, stylesheet);
 
         // sheetData
-        let has_sheet_data = worksheet.get_row_dimensions().len() > 0;
+        let has_sheet_data = worksheet.has_sheet_data();
         write_start_tag(&mut writer, "sheetData", vec![], !has_sheet_data);
 
         // row dimensions sort.
-        let mut row_dimensions = worksheet.get_row_dimensions().clone();
-        row_dimensions.sort_by(|a, b| a.get_row_num().cmp(&b.get_row_num()));
+        let mut row_dimensions = worksheet.get_row_dimensions();
+        row_dimensions.sort_by(|a, b| a.get_row_num().cmp(b.get_row_num()));
+
+        // it's faster than get cell collection by row.
         // cells sort.
-        let mut cells = worksheet.get_cell_collection().clone();
+        let mut cells = worksheet.get_cell_collection();
         cells.sort_by(|a, b| {
             (
                 a.get_coordinate().get_row_num(),
@@ -174,14 +178,9 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             }
 
             // row
-            let include_cell = cells_in_row.len() > 0;
+            let include_cell = !cells_in_row.is_empty();
             if include_cell {
-                let fist_num = cells_in_row
-                    .iter()
-                    .next()
-                    .unwrap()
-                    .get_coordinate()
-                    .get_col_num();
+                let fist_num = cells_in_row.get(0).unwrap().get_coordinate().get_col_num();
                 let last_num = cells_in_row
                     .iter()
                     .last()
@@ -192,7 +191,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
                 row.write_to(&mut writer, stylesheet, spans, false);
                 // c
                 for cell in cells_in_row {
-                    cell.write_to(&mut writer, shared_string_table, stylesheet);
+                    cell.write_to(&mut writer, shared_string_table.clone(), stylesheet);
                 }
                 write_end_tag(&mut writer, "row");
             } else {
