@@ -1,9 +1,6 @@
 extern crate chrono;
 extern crate umya_spreadsheet;
 
-use std::path::PathBuf;
-use umya_spreadsheet::*;
-
 #[test]
 fn read_and_wite() {
     // reader
@@ -11,6 +8,18 @@ fn read_and_wite() {
     let mut book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
     read_and_wite_method(&mut book);
 
+    book.get_sheet_by_name("Sheet1")
+        .unwrap()
+        .get_image("M17")
+        .unwrap()
+        .download_image("./tests/result_files/bbb.png");
+
+    book.get_sheet_by_name_mut("Sheet1")
+        .unwrap()
+        .get_image_mut("M17")
+        .unwrap()
+        .change_image("./images/sample1.png");
+
     // writer
     let path = std::path::Path::new("./tests/result_files/bbb.xlsx");
     let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
@@ -28,6 +37,33 @@ fn lazy_read_and_wite() {
     let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
 }
 
+#[test]
+fn read_large_string() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/aaa_large_string.xlsx");
+    let mut book = umya_spreadsheet::reader::xlsx::lazy_read(path).unwrap();
+    let _ns = book.get_sheet_by_name_mut("Sheet1").unwrap();
+}
+
+#[test]
+fn lazy_read_and_wite_large_string() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/aaa_large_string.xlsx");
+    let mut book = umya_spreadsheet::reader::xlsx::lazy_read(path).unwrap();
+    let ns = book.new_sheet("new sheet").unwrap();
+
+    for r in 1..5000 {
+        for c in 1..30 {
+            let cell = ns.get_cell_by_column_and_row_mut(&c, &r);
+            let _ = cell.set_value_from_string(format!("r{}c{}", r, c));
+        }
+    }
+
+    // writer
+    let path = std::path::Path::new("./tests/result_files/bbb_large_string.xlsx");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
+
 #[test]
 fn lazy_read_and_wite_no_edit() {
     // reader
@@ -40,9 +76,25 @@ fn lazy_read_and_wite_no_edit() {
 }
 
 fn read_and_wite_method(book: &mut umya_spreadsheet::Spreadsheet) {
-    let _ = book.get_sheet_mut(0).get_cell_mut("A1").set_value("TEST1");
+    let _ = book
+        .get_sheet_mut(0)
+        .unwrap()
+        .get_cell_mut("A1")
+        .set_value("TEST1");
     let a1_value = book.get_sheet(0).unwrap().get_value("A1");
     assert_eq!("TEST1", a1_value);
+    let _ = book
+        .get_sheet_mut(0)
+        .unwrap()
+        .remove_cell_by_column_and_row_mut(&1, &1);
+    let a1 = book.get_sheet(0).unwrap().get_cell("A1");
+    assert_eq!(a1, None);
+    let _ = book
+        .get_sheet_mut(0)
+        .unwrap()
+        .remove_cell_by_column_and_row_mut(&1, &2);
+    let a2_value = book.get_sheet(0).unwrap().get_value("A2");
+    assert_eq!(a2_value, "");
     let b5_value = book.get_sheet(0).unwrap().get_value("B5");
     assert_eq!(" ", b5_value);
 
@@ -50,7 +102,7 @@ fn read_and_wite_method(book: &mut umya_spreadsheet::Spreadsheet) {
         "1.0000",
         book.get_sheet(0)
             .unwrap()
-            .get_formatted_value_by_column_and_row(2, 20)
+            .get_formatted_value_by_column_and_row(&2, &20)
     );
     assert_eq!(
         "$3,333.0000",
@@ -136,7 +188,7 @@ fn read_and_wite_method(book: &mut umya_spreadsheet::Spreadsheet) {
         .get_row_dimension_mut(&5u32)
         .get_style_mut()
         .get_fill_mut()
-        .set_pattern_fill(fill.clone());
+        .set_pattern_fill(fill);
     let font_color = umya_spreadsheet::Color::default()
         .set_argb(umya_spreadsheet::Color::COLOR_WHITE)
         .to_owned();
@@ -145,7 +197,7 @@ fn read_and_wite_method(book: &mut umya_spreadsheet::Spreadsheet) {
         .get_row_dimension_mut(&5u32)
         .get_style_mut()
         .get_font_mut()
-        .set_color(font_color.clone());
+        .set_color(font_color);
 }
 
 #[test]
@@ -208,38 +260,54 @@ fn lazy_read_and_wite_xlsm_no_edit() {
 fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     let _ = book
         .get_sheet_mut(0)
-        .get_cell_by_column_and_row_mut(1, 1)
+        .unwrap()
+        .get_cell_by_column_and_row_mut(&1, &1)
         .set_value("TEST1");
     let a1_value = book
         .get_sheet(0)
         .unwrap()
-        .get_cell_by_column_and_row(1, 1)
+        .get_cell_by_column_and_row(&1, &1)
         .unwrap()
         .get_value();
     assert_eq!("TEST1", a1_value);
 
     // copy sheet
     let mut clone_sheet = book.get_sheet(0).unwrap().clone();
-    clone_sheet.set_title("New Sheet");
+    clone_sheet.set_name("New Sheet");
     let _ = book.add_sheet(clone_sheet);
 
+    // remove sheet
+    let mut clone_sheet = book.get_sheet(0).unwrap().clone();
+    clone_sheet.set_name("DeletedSheet");
+    let _ = book.add_sheet(clone_sheet);
+    book.get_sheet_by_name("DeletedSheet").unwrap();
+    book.remove_sheet_by_name("DeletedSheet").unwrap();
+
     // add chart (line chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("A1");
     to_marker.set_coordinate("B2");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::LineChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::LineChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (pie chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -247,17 +315,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("B1");
     to_marker.set_coordinate("C2");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::PieChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::PieChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (doughnut chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -265,17 +341,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("C1");
     to_marker.set_coordinate("D2");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::DoughnutChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::DoughnutChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (area chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -283,17 +367,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("D1");
     to_marker.set_coordinate("E2");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::AreaChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::AreaChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (bar chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -301,17 +393,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("E1");
     to_marker.set_coordinate("F2");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::BarChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::BarChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (bar 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -319,17 +419,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("A2");
     to_marker.set_coordinate("B3");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::Bar3DChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::Bar3DChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (line 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -337,17 +445,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("B2");
     to_marker.set_coordinate("C3");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::Line3DChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::Line3DChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (pie 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -355,17 +471,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("C2");
     to_marker.set_coordinate("D3");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::Pie3DChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::Pie3DChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (area 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -373,17 +497,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("D2");
     to_marker.set_coordinate("E3");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::Area3DChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::Area3DChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (of pie chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -391,17 +523,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("E2");
     to_marker.set_coordinate("F3");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::OfPieChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::OfPieChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (bubble chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -413,17 +553,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
         "New Sheet!$H$7:$H$10",
         "New Sheet!$I$7:$I$10",
     ];
+    let series_title_list = vec!["Line1", "Line2", "Line3"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::BubbleChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::BubbleChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (radar chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -435,17 +583,25 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
         "New Sheet!$H$7:$H$10",
         "New Sheet!$I$7:$I$10",
     ];
+    let series_title_list = vec!["Line1", "Line2", "Line3"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::RadarChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::RadarChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
 
     // add chart (scatter chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -453,17 +609,35 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     from_marker.set_coordinate("C3");
     to_marker.set_coordinate("D4");
     let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
+    let series_title_list = vec!["Line1", "Line2"];
+    let series_point_title_list = vec!["Point1", "Point2", "Point3", "Point4"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
-    chart.new_chart(
-        umya_spreadsheet::structs::ChartType::ScatterChart,
-        from_marker,
-        to_marker,
-        area_chart_series_list,
-    );
+    chart
+        .new_chart(
+            umya_spreadsheet::structs::ChartType::ScatterChart,
+            from_marker,
+            to_marker,
+            area_chart_series_list,
+        )
+        .set_series_title(series_title_list)
+        .set_series_point_title(series_point_title_list)
+        .set_default_language("ja-JP")
+        .set_title("Chart Title")
+        .set_horizontal_title("Horizontal Title")
+        .set_vertical_title("Vertical Title");
     book.get_sheet_by_name_mut("Sheet7")
         .unwrap()
-        .get_worksheet_drawing_mut()
-        .add_chart_collection(chart);
+        .add_chart(chart);
+
+    // Add Image
+    let _ = book.new_sheet("Sheet Image");
+    let mut marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
+    marker.set_coordinate("B3");
+    let mut image = umya_spreadsheet::structs::Image::default();
+    image.new_image("./images/sample1.png", marker);
+    book.get_sheet_by_name_mut("Sheet Image")
+        .unwrap()
+        .add_image(image);
 }
 
 #[test]
@@ -472,12 +646,12 @@ fn insert_and_remove_cells() {
     let path = std::path::Path::new("./tests/test_files/aaa_insertCell.xlsx");
     let mut book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
 
-    book.insert_new_row("Sheet1", 2, 3);
-    book.insert_new_colmun("Sheet1", "B", 3);
-    book.insert_new_colmun_by_index("Sheet1", 2, 3);
+    book.insert_new_row("Sheet1", &2, &3);
+    book.insert_new_column("Sheet1", "B", &3);
+    book.insert_new_column_by_index("Sheet1", &2, &3);
 
-    book.remove_row("Sheet1", 6, 2);
-    book.remove_colmun_by_index("Sheet1", 6, 2);
+    book.remove_row("Sheet1", &6, &2);
+    book.remove_column_by_index("Sheet1", &6, &2);
 
     // writer
     let path = std::path::Path::new("./tests/result_files/bbb_insertCell.xlsx");
@@ -508,48 +682,48 @@ fn new_file_and_edit() {
 
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row_mut(2, 2)
+        .get_cell_by_column_and_row_mut(&2, &2)
         .set_value_from_i32(1);
     let a1_value = book
         .get_sheet_by_name("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row(2, 2)
+        .get_cell_by_column_and_row(&2, &2)
         .unwrap()
         .get_value();
     assert_eq!("1", a1_value);
 
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row_mut(2, 2)
+        .get_cell_by_column_and_row_mut(&2, &2)
         .set_value_from_i32_ref(&1);
     let a1_value = book
         .get_sheet_by_name("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row(2, 2)
+        .get_cell_by_column_and_row(&2, &2)
         .unwrap()
         .get_value();
     assert_eq!("1", a1_value);
 
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row_mut(3, 3)
+        .get_cell_by_column_and_row_mut(&3, &3)
         .set_value_from_bool(true);
     let a1_value = book
         .get_sheet_by_name("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row(3, 3)
+        .get_cell_by_column_and_row(&3, &3)
         .unwrap()
         .get_value();
     assert_eq!("TRUE", a1_value);
 
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row_mut(3, 3)
+        .get_cell_by_column_and_row_mut(&3, &3)
         .set_value_from_bool_ref(&true);
     let a1_value = book
         .get_sheet_by_name("Sheet2")
         .unwrap()
-        .get_cell_by_column_and_row(3, 3)
+        .get_cell_by_column_and_row(&3, &3)
         .unwrap()
         .get_value();
     assert_eq!("TRUE", a1_value);
@@ -563,7 +737,7 @@ fn new_file_and_edit() {
         .set_border_style(umya_spreadsheet::Border::BORDER_MEDIUM);
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .get_style_by_column_and_row_mut(3, 2)
+        .get_style_by_column_and_row_mut(&3, &2)
         .get_borders_mut()
         .get_left_mut()
         .set_border_style(umya_spreadsheet::Border::BORDER_THIN);
@@ -576,6 +750,28 @@ fn new_file_and_edit() {
         .get_color_mut()
         .set_argb("00FF0000");
 
+    // change background color.
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_style_mut("A1")
+        .get_fill_mut()
+        .get_pattern_fill_mut()
+        .get_foreground_color_mut()
+        .set_argb(umya_spreadsheet::Color::COLOR_BLUE);
+
+    // change background color part2.
+    let mut color = umya_spreadsheet::Color::default();
+    color.set_argb(umya_spreadsheet::Color::COLOR_BLUE);
+    let mut pattern_fill = umya_spreadsheet::PatternFill::default();
+    pattern_fill.set_foreground_color(color);
+    let mut fill = umya_spreadsheet::Fill::default();
+    fill.set_pattern_fill(pattern_fill);
+    let mut style = umya_spreadsheet::Style::default();
+    style.set_fill(fill);
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .set_style("A2", style);
+    
     let worksheet = book.get_sheet_by_name_mut("Sheet3").unwrap();
     worksheet.get_column_dimension_mut("A").set_auto_width(true);
 
@@ -681,3 +877,37 @@ fn duplicate_sheet() {
         Err(_) => {}
     }
 }
+
+#[test]
+fn witer_csv() {
+    let mut book = umya_spreadsheet::new_file();
+    book.set_active_sheet(1);
+    let sheet = book.new_sheet("Sheet2").unwrap();
+    // ---
+    sheet.get_cell_mut("A1").set_value(" TEST");
+    sheet.get_cell_mut("B1").set_value("あいうえお");
+    sheet.get_cell_mut("C1").set_value("漢字");
+    sheet.get_cell_mut("E1").set_value("1");
+    // ---
+    sheet.get_cell_mut("A2").set_value("TEST ");
+    sheet.get_cell_mut("B2").set_value("あいうえお");
+    sheet.get_cell_mut("C2").set_value("漢字");
+    // ---
+    sheet.get_cell_mut("A3").set_value(" TEST ");
+    // ---
+
+    // writer
+    let mut option = umya_spreadsheet::structs::CsvWriterOption::default();
+    option.set_csv_encode_value(umya_spreadsheet::structs::CsvEncodeValues::ShiftJis);
+    option.set_do_trim(true);
+    option.set_wrap_with_char("\"");
+    let path = std::path::Path::new("./tests/result_files/bbb.csv");
+    let _ = umya_spreadsheet::writer::csv::write(&book, path, Some(&option));
+}
+
+#[test]
+fn new_file_empty_worksheet() {
+    let book = umya_spreadsheet::new_file_empty_worksheet();
+    let path = std::path::Path::new("./tests/result_files/empty_worksheet.xlsx");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
